@@ -17,13 +17,12 @@
 */
 
 
-#ifndef PLOUF_H__
-#define PLOUF_H__
+#ifndef __ABOUT_H__
+#define __ABOUT_H__
 
 
-#include <gtk/gtk.h>
-
-void get_about_dialog();
+#include <gnome.h>
 
+void about_gtktalog ();
 
 #endif
