@@ -23,6 +23,14 @@
 #    include <sys/mount.h>
 #endif
 #include <gnome.h>
+#ifdef USE_GNOMEVFS
+#include <libgnomevfs/gnome-vfs-mime.h>
+#ifdef GNOME1
+#include <libgnomevfs/gnome-vfs-uri.h>
+#else
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#endif
+#endif
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/resource.h>
@@ -37,6 +45,7 @@
 #    include <pthread.h>
 #endif
 #include <signal.h>
+#include <setjmp.h>
 
 #include "addisk.h"
 #include "config_common.h"
@@ -73,6 +82,16 @@ static gint current_progressbar;
 static gchar *mosx_cd_mount_point = NULL;
 #endif
 
+#ifdef USE_SETJMP
+jmp_buf context;
+
+void
+sigalrm_handler (int i)
+{
+  longjmp (context, 1);
+}
+#endif
+
 gint
 spawn_proc (gchar * path, gint narg, gchar ** arg)
 {
@@ -129,7 +148,7 @@ du_s (gchar * path)
 	   * in order not to have error messages on the console
 	   */
 	  argsdu[0] = g_strdup ("du");
-#if defined(OS_LINUX)
+#if defined(OS_LINUX) || defined(__CYGWIN__)
 	  argsdu[1] = g_strdup ("-sb");
 #elif defined(OS_FREEBSD) || defined(OS_NETBSD) || defined(OS_OPENBSD) || defined(OS_PPC_DARWIN)
 	  argsdu[1] = g_strdup ("-s");
@@ -203,17 +222,17 @@ eject_disk (CONFIG * my_config)
   seteuid (getuid ());
   if (my_config->use_sudo)
     {
-  args[0] = my_config->sudo;
-  args[1] = my_config->eject_prog->str;
-  args[2] = my_config->mount_device->str;
-  pid = spawn_proc (NULL, 3, args);
+      args[0] = my_config->sudo;
+      args[1] = my_config->eject_prog->str;
+      args[2] = my_config->mount_device->str;
+      pid = spawn_proc (NULL, 3, args);
     }
   else
     {
-  args[0] = my_config->eject_prog->str;
-  args[1] = my_config->mount_device->str;
-  pid = spawn_proc (NULL, 2, args);
-  }
+      args[0] = my_config->eject_prog->str;
+      args[1] = my_config->mount_device->str;
+      pid = spawn_proc (NULL, 2, args);
+    }
   if (pid == -1)
     {
       set_message_to_display (g_string_new
@@ -240,7 +259,7 @@ eject_disk (CONFIG * my_config)
 gboolean
 mount_disk (CONFIG * my_config)
 {
-#if defined(OS_LINUX) || defined(OS_NETBSD) || defined(OS_OPENBSD)
+#if defined(OS_LINUX) || defined(OS_NETBSD) || defined(OS_OPENBSD) || defined(OS_FREEBSD)
   int pid, status;
   char *args[3];
   int nargs;
@@ -249,15 +268,15 @@ mount_disk (CONFIG * my_config)
   seteuid (getuid ());
   if (my_config->use_sudo)
     {
-  args[0] = my_config->sudo;
-  args[1] = my_config->mount->str;
-  args[2] = my_config->mount_point->str;
-  nargs = 3;
+      args[0] = my_config->sudo;
+      args[1] = my_config->mount->str;
+      args[2] = my_config->mount_point->str;
+      nargs = 3;
     }
   else
     {
-  args[0] = my_config->mount->str;
-  args[1] = my_config->mount_point->str;
+      args[0] = my_config->mount->str;
+      args[1] = my_config->mount_point->str;
       nargs = 2;
     }
 
@@ -290,20 +309,6 @@ mount_disk (CONFIG * my_config)
 
   set_message_to_display (g_string_new (_("Mount failed! Disk in use?")));
   return (FALSE);
-#elif defined(OS_FREEBSD)
-  int status;
-  struct iso_args args;
-
-  args.export.ex_flags = MNT_EXRDONLY;
-  args.fspec = "/dev/cd0a";	// Will be changed
-  args.export.ex_root = -2;
-  status =
-    mount (MOUNT_CD9660, my_config->mount_point->str, MNT_RDONLY, &args);
-  /* error saved in errno variable, do something with it */
-  if (status == 0)
-    return (TRUE);
-  else
-    return (FALSE);
 #elif defined(OS_PPC_DARWIN)
   /*
    * with MacOS X, CD are mounted automatically so, 
@@ -319,7 +324,7 @@ mount_disk (CONFIG * my_config)
 gboolean
 umount_disk (CONFIG * my_config)
 {
-#if defined(OS_LINUX) || defined(OS_NETBSD) || defined(OS_OPENBSD)
+#if defined(OS_LINUX) || defined(OS_NETBSD) || defined(OS_OPENBSD) || defined(OS_FREEBSD)
   int pid, status;
   int nargs;
   char *args[3];
@@ -327,15 +332,15 @@ umount_disk (CONFIG * my_config)
   seteuid (getuid ());
   if (my_config->use_sudo)
     {
-  args[0] = my_config->sudo;
-  args[1] = my_config->umount->str;
-  args[2] = my_config->mount_point->str;
-  nargs = 3;
+      args[0] = my_config->sudo;
+      args[1] = my_config->umount->str;
+      args[2] = my_config->mount_point->str;
+      nargs = 3;
     }
   else
     {
-  args[0] = my_config->umount->str;
-  args[1] = my_config->mount_point->str;
+      args[0] = my_config->umount->str;
+      args[1] = my_config->mount_point->str;
       nargs = 2;
     }
   pid = spawn_proc (NULL, nargs, args);
@@ -361,14 +366,6 @@ umount_disk (CONFIG * my_config)
       return (FALSE);
     }
   return (TRUE);
-#elif defined(OS_FREEBSD)
-  int status;
-
-  status = unmount (my_config->mount_point->str, NULL);
-  if (status == 0)
-    return (TRUE);
-  else
-    return (FALSE);
 #elif defined(OS_PPC_DARWIN)
   set_message_to_display (g_string_new (_("Umount failed! Disk in use?")));
   return (FALSE);
@@ -378,25 +375,24 @@ umount_disk (CONFIG * my_config)
 void
 umount_and_eject_if_necessary (void)
 {
-  if (flag_to_umount == TRUE)
+  if (flag_to_umount)
     {
       /* umount the drive and eject it */
-	  if ((my_config->use_supermount == TRUE)
-	      || (my_config->use_automount == TRUE))
+      if ((my_config->use_supermount) || (my_config->use_automount))
 	{
-	  if (my_config->eject_disk == TRUE)
+	  if (my_config->eject_disk)
 	    {
-	    eject_disk (my_config);
+	      eject_disk (my_config);
 	    }
 	}
-	  else if (umount_disk (my_config) == TRUE)
+      else if (umount_disk (my_config))
 	{
-	  if (my_config->eject_disk == TRUE)
+	  if (my_config->eject_disk)
 	    {
-	    eject_disk (my_config);
+	      eject_disk (my_config);
+	    }
 	}
     }
-    }
 
 }
 
@@ -502,7 +498,8 @@ my_timeout (gpointer data)
 	}
       if (stop_window)
 	{
-	  progress_setCurrent (progress_getTotal_m (GNOMEAPPBAR_SCAN),progress_getTotal_b (GNOMEAPPBAR_SCAN),
+	  progress_setCurrent (progress_getTotal_m (GNOMEAPPBAR_SCAN),
+			       progress_getTotal_b (GNOMEAPPBAR_SCAN),
 			       GNOMEAPPBAR_SCAN);
 	  progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SCAN));
 	  current_progressbar = GNOMEAPPBAR_MAIN;
@@ -523,13 +520,13 @@ my_timeout (gpointer data)
 /************** If umount and eject have to be in the main thread, remove the comments ********/
 //umount_and_eject_if_necessary();
 /*********************************************************************************************/
-      progress_setCurrent (progress_getTotal_b (current_progressbar),progress_getTotal_b (current_progressbar),
+      progress_setCurrent (progress_getTotal_b (current_progressbar),
+			   progress_getTotal_b (current_progressbar),
 			   current_progressbar);
       progress_timeout (GINT_TO_POINTER (current_progressbar));
 
       reinit_thread_status ();
-      progress_addCurrent ( 1,
-			   GNOMEAPPBAR_MAIN);
+      progress_addCurrent (1, GNOMEAPPBAR_MAIN);
       progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_MAIN));
       if (vfs_scan_nok)
 	{
@@ -551,8 +548,7 @@ my_timeout (gpointer data)
 void
 fad_wait_window_cb (GtkWidget * w, gpointer data)
 {
-  progress_addCurrent ( 1,
-		       GNOMEAPPBAR_SCAN);
+  progress_addCurrent (1, GNOMEAPPBAR_SCAN);
   progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SCAN));
   current_progressbar = GNOMEAPPBAR_MAIN;
   progress_setGnomeAppBar (NULL, GNOMEAPPBAR_SCAN, FALSE);
@@ -564,8 +560,7 @@ fad_wait_window_cb (GtkWidget * w, gpointer data)
 static void
 destroy_fad_window (GtkWidget * w, GdkEventKey * event, gpointer data)
 {
-  progress_addCurrent ( 1,
-		       GNOMEAPPBAR_SCAN);
+  progress_addCurrent (1, GNOMEAPPBAR_SCAN);
   progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SCAN));
   current_progressbar = GNOMEAPPBAR_MAIN;
   progress_setGnomeAppBar (NULL, GNOMEAPPBAR_SCAN, FALSE);
@@ -603,10 +598,14 @@ fad_wait_window (void)
 
   progress_setGnomeAppBar (progressbar, GNOMEAPPBAR_SCAN, FALSE);
   progress_set_activity_mode (GNOMEAPPBAR_SCAN, FALSE);
-  progress_setCurrent (progress_getCurrent_m (GNOMEAPPBAR_MAIN),progress_getCurrent_b (GNOMEAPPBAR_MAIN),
+  progress_setCurrent (progress_getCurrent_m (GNOMEAPPBAR_MAIN),
+		       progress_getCurrent_b (GNOMEAPPBAR_MAIN),
 		       GNOMEAPPBAR_SCAN);
-  progress_setTotal (progress_getTotal_m (GNOMEAPPBAR_MAIN), progress_getTotal_b (GNOMEAPPBAR_MAIN), GNOMEAPPBAR_SCAN);
-  progress_setCurrent (progress_getTotal_m (GNOMEAPPBAR_MAIN),progress_getTotal_b (GNOMEAPPBAR_MAIN),
+  progress_setTotal (progress_getTotal_m (GNOMEAPPBAR_MAIN),
+		     progress_getTotal_b (GNOMEAPPBAR_MAIN),
+		     GNOMEAPPBAR_SCAN);
+  progress_setCurrent (progress_getTotal_m (GNOMEAPPBAR_MAIN),
+		       progress_getTotal_b (GNOMEAPPBAR_MAIN),
 		       GNOMEAPPBAR_MAIN);
   current_progressbar = GNOMEAPPBAR_SCAN;
 #if !defined(USE_PTHREADS)
@@ -616,19 +615,19 @@ fad_wait_window (void)
 
   /* Callbacks */
   gnome_dialog_button_connect (GNOME_DIALOG (stop_window), 0,
-			       fad_wait_window_cb,
+			       G_CALLBACK (fad_wait_window_cb),
 			       GINT_TO_POINTER (ADDED_DISK_STOP));
   gnome_dialog_button_connect (GNOME_DIALOG (stop_window), 1,
-			       fad_wait_window_cb,
+			       G_CALLBACK (fad_wait_window_cb),
 			       GINT_TO_POINTER (ADDED_DISK_DELETE));
 
   gtk_window_set_modal (GTK_WINDOW (stop_window), TRUE);
   gtk_window_set_transient_for (GTK_WINDOW (stop_window),
 				GTK_WINDOW (main_window));
   gtk_signal_connect (GTK_OBJECT (stop_window),
-		      "delete_event", destroy_fad_window, NULL);
+		      "delete_event", G_CALLBACK (destroy_fad_window), NULL);
   gtk_signal_connect (GTK_OBJECT (stop_window),
-		      "close", destroy_fad_window, NULL);
+		      "close", G_CALLBACK (destroy_fad_window), NULL);
   gtk_widget_realize (stop_window);
   gtk_widget_show (stop_window);
 
@@ -712,15 +711,17 @@ launch_information_plugin (gchar * file, MIME_EXTENSIONS * m)
 	  b = read (0, buff, 249 * sizeof (char));
 	  while (b != 0)
 	    {
-	      buff[b] = '\0';
-	      information = g_string_append (information, buff);
+	      if (b >= 0)
+		{
+		  buff[b] = '\0';
+		  information = g_string_append (information, buff);
+		}
 	      b = read (0, buff, 249 * sizeof (char));
 	    }
 	  wait4 (pid, &status, 0, NULL);
 	  ret = g_strdup (information->str);
 	  g_string_free (information, TRUE);
 	  return (ret);
-
 	}
     }
   else
@@ -751,7 +752,7 @@ read_information (gchar * file, gchar * mime)
       if (my_config->use_default_information_plugin)
 	{
 	  m = my_config->default_information_plugin;
-	  if (m->state == TRUE)
+	  if (m->state)
 	    {
 	      information_string = launch_information_plugin (file, m);
 	    }
@@ -815,6 +816,11 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   gchar *infostring;
   gchar *mime;
   gpointer scan_it;
+#ifdef GNOME1
+#ifdef USE_GNOMEVFS
+  GnomeVFSURI *file_uri;
+#endif
+#endif
 
   if (added_disk_is_ok == ADDED_DISK_DELETE)
     {
@@ -846,8 +852,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 	 && (added_disk_is_ok != ADDED_DISK_STOP))
     {
       file = g_strconcat (my_path->str, fichier->d_name, NULL);
-      if ((strcmp (fichier->d_name, ".") )
-	  && (strcmp (fichier->d_name, "..") ))
+      if ((strcmp (fichier->d_name, ".")) && (strcmp (fichier->d_name, "..")))
 	{
 
 	  if (lstat (file, &fileinfo) == -1)
@@ -907,10 +912,35 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 	      mime = NULL;
 	      if (my_config->scan_mime_types)
 		{
-		  mime = g_strdup (gnome_mime_type_from_magic (file));
+//printf("%s %d %s\n", __FILE__,__LINE__,file);
+#ifdef USE_SETJMP
+		  signal (SIGALRM, sigalrm_handler);
+		  alarm (5);
+		  if (!setjmp (context))
+#endif
+#ifdef GNOME1
+#ifdef USE_GNOMEVFS
+//            printf("%s %d <%s>\n", __FILE__,__LINE__,file);
+		    file_uri = gnome_vfs_uri_new (file);
+//            printf("%s %d\n", __FILE__,__LINE__);
+		  mime = g_strdup (gnome_vfs_get_mime_type (file_uri));
+		  gnome_vfs_uri_unref (file_uri);
+#else
+		    mime = g_strdup (gnome_vfs_get_mime_type (file));
+#endif
+#else
+		    mime = g_strdup (gnome_vfs_get_mime_type (file));
+#endif
+#ifdef USE_SETJMP
+		  alarm (0);
+#endif
+//printf("%s %d %s\n", __FILE__,__LINE__,file);
 		}
 	      if (!mime)
-		mime = g_strdup (gnome_mime_type_or_default (file, NULL));
+		mime =
+		  g_strdup (gnome_vfs_mime_type_from_name_or_default
+			    (file, NULL));
+
 	      if (mime)
 		{
 		  scan_it =
@@ -942,7 +972,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 		    g_free (infostring);
 		  if (testvfs != TEST_VFS_NO)
 		    {
-		      if (vfs_read (gn, fichier->d_name, testvfs, racine))
+		      if (vfs_read (gn, file, testvfs, racine))
 			vfs_scan_nok = TRUE;
 		    }
 		}
@@ -952,9 +982,11 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 		    g_free (mime);
 		}
 	    }
-	} else {
-		  if (lstat (file, &fileinfo) >=0)
-	      progress_addCurrent (fileinfo.st_size, current_progressbar);
+	}
+      else
+	{
+	  if (lstat (file, &fileinfo) >= 0)
+	    progress_addCurrent (fileinfo.st_size, current_progressbar);
 
 	}
       g_free (file);
@@ -1031,7 +1063,7 @@ check_mounted (CONFIG * my_config)
 int
 mount_disk_if_necessary (void)
 {
-  if (flag_to_mount == TRUE)
+  if (flag_to_mount)
     {
       flag_to_umount = FALSE;
       if ((my_config->use_supermount == FALSE)
@@ -1084,12 +1116,12 @@ start_thread_scan (void *arg)
   guint l;
 #if defined(USE_PTHREADS)
   current_progressbar = GNOMEAPPBAR_MAIN;
-  progress_setTotal (0,0, GNOMEAPPBAR_SCAN);
+  progress_setTotal (0, 0, GNOMEAPPBAR_SCAN);
 #else
   current_progressbar = GNOMEAPPBAR_SCAN;
 #endif
-  progress_setCurrent (0,0, current_progressbar);
-  progress_setTotal (0,0, current_progressbar);
+  progress_setCurrent (0, 0, current_progressbar);
+  progress_setTotal (0, 0, current_progressbar);
 #if defined(__DEBUG__)
   GML_log (2, "start_thread_scan()\n");
 #endif
@@ -1108,11 +1140,11 @@ start_thread_scan (void *arg)
       return (NULL);
     }
 
-  if (my_config->use_du_s == TRUE)
+  if (my_config->use_du_s)
     l = du_s (local_foldername);
   else
     l = getStats (my_config->mount_device->str);
-  progress_setTotal (0,l, current_progressbar);
+  progress_setTotal (0, l, current_progressbar);
 
   /* Launch the update of the progress bar */
 /*  progress_createTimeout ();*/
