@@ -42,7 +42,10 @@
 #include "setup.h"
 #include "thread_utils.h"
 
+#define TOOLBAR_NB_OF_ELEMENTS	10
+
 GnomeUIInfo *toolbar;
+GtkWidget *toolbar_widget;
 GnomeUIInfo general_toolbar[] = {
 /*00*/ GNOMEUIINFO_SEPARATOR,
 /*01*/ GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("New catalog"),
@@ -62,8 +65,9 @@ GnomeUIInfo general_toolbar[] = {
 /*07*/ GNOMEUIINFO_ITEM_STOCK (N_("Find file"), N_("Find file"),
 			       cb_create_search_dialog,
 			       GNOME_STOCK_PIXMAP_SEARCH),
-/*08*/ GNOMEUIINFO_ITEM_NONE (N_("Create Report"), N_("Create Report"),
-			      cb_open_report_dialog),
+/*08*/ GNOMEUIINFO_ITEM_STOCK (N_("Create Report"), N_("Create Report"),
+			       cb_open_report_dialog,
+			       GNOME_STOCK_PIXMAP_BOOK_GREEN),
 /*09*/ GNOMEUIINFO_ITEM_STOCK (N_("Add CD"), N_("Add CD"),
 			       cb_fast_add_disk, GNOME_STOCK_PIXMAP_CDROM),
 /*10*/ GNOMEUIINFO_ITEM_STOCK (N_("Add dir"), N_("Add dir"),
@@ -75,10 +79,11 @@ GnomeUIInfo general_toolbar[] = {
 };
 
 void
-enable_gnome_button_bar (GtkWidget * window, gpointer data)
+enable_gnome_button_bar (GtkWidget * window, gint type)
 {
+  toolbar =
+    (GnomeUIInfo *) g_malloc (TOOLBAR_NB_OF_ELEMENTS * sizeof (GnomeUIInfo));
 
-  toolbar = (GnomeUIInfo *) g_malloc (14 * sizeof (GnomeUIInfo));
   /* Copy the items from the general toolbar to the toolbar.
    * toolbar is the toolbar that will be displayed.
    * This way makes it easy to program customization later as it
@@ -87,30 +92,54 @@ enable_gnome_button_bar (GtkWidget * window, gpointer data)
   memcpy (&(toolbar[0]), &(general_toolbar[1]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[1]), &(general_toolbar[2]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[2]), &(general_toolbar[3]), sizeof (GnomeUIInfo));
-
   memcpy (&(toolbar[3]), &(general_toolbar[0]), sizeof (GnomeUIInfo));
-
   memcpy (&(toolbar[4]), &(general_toolbar[9]), sizeof (GnomeUIInfo));
-  memcpy (&(toolbar[5]), &(general_toolbar[10]), sizeof (GnomeUIInfo));
+  memcpy (&(toolbar[5]), &(general_toolbar[8]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[6]), &(general_toolbar[7]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[7]), &(general_toolbar[0]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[8]), &(general_toolbar[11]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[9]), &(general_toolbar[12]), sizeof (GnomeUIInfo));
 
   gnome_app_create_toolbar_with_data (GNOME_APP (window), toolbar, NULL);
+  /* The last GnomeUIInfo item contains the toolbar widget as the .widget field */
+  toolbar_widget = toolbar[TOOLBAR_NB_OF_ELEMENTS - 1].widget;
+  update_toolbar_style ();
+}
+
+void
+update_toolbar_style ()
+{
+  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar_widget),
+			 my_config->toolbar_type);
 }
 
 void
 buttons_set_sensitive (gboolean sensitive)
 {
   gtk_widget_set_sensitive (GTK_WIDGET (toolbar[2].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (toolbar[5].widget), sensitive);
   gtk_widget_set_sensitive (GTK_WIDGET (toolbar[6].widget), sensitive);
 }
 
+void
+buttons_set_all_sensitive (gboolean sensitive)
+{
+  int i;
+  for (i = 0; i < TOOLBAR_NB_OF_ELEMENTS; i++)
+    {
+      if (toolbar[i].widget)
+	{
+	  gtk_widget_set_sensitive (GTK_WIDGET (toolbar[i].widget),
+				    sensitive);
+	}
+    }
+}
+
 void
 cb_new_file (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       new_file ();
     }
@@ -122,8 +151,10 @@ cb_open_recent (GtkWidget * w, gpointer data)
   FOLDER *racine;
   gchar *p;
   gchar *filename = data;
+  gint l;
 
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine != NULL)
 	{
@@ -153,7 +184,8 @@ cb_open_recent (GtkWidget * w, gpointer data)
  * so we do not keep something pointing to it to free it after
  */
       filename = g_strdup (filename);
-      if (load_cat_from_file (filename, my_config->racine) == -1)
+      l = load_cat_from_file (filename, my_config->racine);
+      if (l == -1)
 	{
 	  return;
 	}
@@ -173,24 +205,43 @@ cb_open_recent (GtkWidget * w, gpointer data)
 
       gtk_window_set_title (GTK_WINDOW (main_window), filename);
       menus_set_sensitive (TRUE);
+      if (l == -2)
+	{
+	  WARNING_DIALOG (_
+			  ("At least one disk name was empty. A random name was used instead"),
+			  main_window);
+	}
+
     }
 }
 
 void
 cb_open_cat (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       open_cat (my_config->racine);
     }
 }
 
+void
+cb_merge_cat (GtkWidget * w, gpointer data)
+{
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
+    {
+      merge_cat (my_config->racine);
+    }
+}
+
 void
 cb_fast_save (GtkWidget * w, gpointer data)
 {
   if (my_config->racine)
     {
-      if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+	  && (!is_search_running ()))
 	{
 	  fast_save (my_config->racine);
 	}
@@ -202,7 +253,8 @@ cb_save_cat (GtkWidget * w, gpointer data)
 {
   if (my_config->racine)
     {
-      if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+	  && (!is_search_running ()))
 	{
 	  save_cat (my_config->racine);
 	}
@@ -212,7 +264,8 @@ cb_save_cat (GtkWidget * w, gpointer data)
 void
 cb_quit_prog (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       quit_prog (my_config->racine);
     }
@@ -221,7 +274,8 @@ cb_quit_prog (GtkWidget * w, gpointer data)
 void
 cb_edit_categories (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine)
 	{
@@ -233,7 +287,8 @@ cb_edit_categories (GtkWidget * w, gpointer data)
 void
 cb_run_setup (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       run_setup ();
     }
@@ -242,11 +297,22 @@ cb_run_setup (GtkWidget * w, gpointer data)
 void
 cb_create_search_dialog (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine)
 	{
-	  create_search_dialog (my_config->racine);
+	  if (g_node_n_nodes (my_config->racine->tree, G_TRAVERSE_ALL) > 1)
+	    {
+	      set_search_running (TRUE);
+	      menus_set_all_sensitive (FALSE);
+
+	      create_search_dialog (my_config->racine);
+	    }
+	  else
+	    ERROR_DIALOG (_
+			  ("The catalog is empty: nothing to search!"),
+			  main_window);
 	}
     }
 }
@@ -254,11 +320,17 @@ cb_create_search_dialog (GtkWidget * w, gpointer data)
 void
 cb_open_report_dialog (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine)
 	{
-	  open_report_dialog (my_config->racine);
+	  if (g_node_n_nodes (my_config->racine->tree, G_TRAVERSE_ALL) > 1)
+	    open_report_dialog (my_config->racine);
+	  else
+	    ERROR_DIALOG (_
+			  ("The catalog is empty: nothing to write in a report!"),
+			  main_window);
 	}
     }
 }
@@ -266,7 +338,8 @@ cb_open_report_dialog (GtkWidget * w, gpointer data)
 void
 cb_fast_add_disk (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine == NULL)
 	{
@@ -283,7 +356,8 @@ cb_fast_add_disk (GtkWidget * w, gpointer data)
 void
 cb_show_select_dir_win (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine == NULL)
 	{
@@ -292,6 +366,8 @@ cb_show_select_dir_win (GtkWidget * w, gpointer data)
 	  add_gnode_to_ctree (my_config->racine->tree, my_config->racine);
 	  ctree_window_add (my_config->racine->ctree);
 	  menus_set_sensitive (TRUE);
+	  update_tree (my_config->racine);
+
 	}
       show_select_dir_win (my_config->racine);
     }
@@ -300,7 +376,8 @@ cb_show_select_dir_win (GtkWidget * w, gpointer data)
 void
 cb_cat_info (GtkWidget * w, gpointer data)
 {
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
+  if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+      && (!is_search_running ()))
     {
       if (my_config->racine)
 	{
