@@ -23,22 +23,29 @@
 #include <gnome.h>
 #include "config_common.h"
 
-void enable_gnome_button_bar (GtkWidget * window, gpointer data);
+#define TOOLBAR_TYPE_TEXT_ICONS 0
+#define TOOLBAR_TYPE_TEXT_ONLY 1
+#define TOOLBAR_TYPE_ICONS_ONLY 2
+
+void enable_gnome_button_bar (GtkWidget * window, gint type);
+void update_toolbar_style ();
 void buttons_set_sensitive (gboolean sensitive);
-void cb_new_file (GtkWidget *w, gpointer data);
-void cb_open_recent (GtkWidget *w, gpointer data);
-void cb_open_cat (GtkWidget *w, gpointer data);
-void cb_fast_save (GtkWidget *w, gpointer data);
-void cb_save_cat (GtkWidget *w, gpointer data);
-void cb_quit_prog (GtkWidget *w, gpointer data);
-void cb_edit_categories (GtkWidget *w, gpointer data);
-void cb_run_setup (GtkWidget *w, gpointer data);
-void cb_create_search_dialog (GtkWidget *w, gpointer data);
-void cb_open_report_dialog (GtkWidget *w, gpointer data);
-void cb_fast_add_disk (GtkWidget *w, gpointer data);
-void cb_show_select_dir_win (GtkWidget *w, gpointer data);
+void buttons_set_all_sensitive (gboolean sensitive);
+void cb_new_file (GtkWidget * w, gpointer data);
+void cb_open_recent (GtkWidget * w, gpointer data);
+void cb_open_cat (GtkWidget * w, gpointer data);
+void cb_merge_cat (GtkWidget * w, gpointer data);
+void cb_fast_save (GtkWidget * w, gpointer data);
+void cb_save_cat (GtkWidget * w, gpointer data);
+void cb_quit_prog (GtkWidget * w, gpointer data);
+void cb_edit_categories (GtkWidget * w, gpointer data);
+void cb_run_setup (GtkWidget * w, gpointer data);
+void cb_create_search_dialog (GtkWidget * w, gpointer data);
+void cb_open_report_dialog (GtkWidget * w, gpointer data);
+void cb_fast_add_disk (GtkWidget * w, gpointer data);
+void cb_show_select_dir_win (GtkWidget * w, gpointer data);
 void cb_cat_info (GtkWidget * w, gpointer data);
-void cb_about_gtktalog (GtkWidget *w, gpointer data);
+void cb_about_gtktalog (GtkWidget * w, gpointer data);
 
 
 #endif
