@@ -431,7 +431,7 @@ edit_categories (FOLDER * racine)
 
   gtk_window_set_title (GTK_WINDOW (cat_window), _("Category editor"));
   gtk_signal_connect (GTK_OBJECT (cat_window),
-		      "delete_event", destroy_window, racine);
+		      "delete_event", GTK_SIGNAL_FUNC(destroy_window), racine);
   gtk_window_set_policy (GTK_WINDOW (cat_window), FALSE, TRUE, TRUE);
 
   gtk_widget_show (cat_window);
@@ -512,7 +512,11 @@ edit_categories (FOLDER * racine)
 		      GTK_SIGNAL_FUNC (remove_unused_clicked), racine);
 
 
+#ifdef GNOME1
   button_add = gnome_stock_or_ordinary_button ("Add");
+#else
+  button_add = gtk_button_new_from_stock ("Add");
+#endif
   gtk_box_pack_start (GTK_BOX (vbox1), button_add, TRUE, FALSE, 0);
   gtk_widget_show (button_add);
   gtk_signal_connect (GTK_OBJECT (button_add), "clicked",
@@ -526,7 +530,11 @@ edit_categories (FOLDER * racine)
 		      GTK_SIGNAL_FUNC (edit_the_categorie), racine);
   gtk_widget_set_sensitive (GTK_WIDGET (button_edit), FALSE);
 
+#ifdef GNOME1
   button_delete = gnome_stock_or_ordinary_button ("Remove");
+#else
+  button_delete = gtk_button_new_from_stock ("Remove");
+#endif
   gtk_box_pack_start (GTK_BOX (vbox1), button_delete, TRUE, FALSE, 0);
   gtk_widget_show (button_delete);
   gtk_signal_connect (GTK_OBJECT (button_delete), "clicked",
@@ -534,7 +542,11 @@ edit_categories (FOLDER * racine)
   gtk_widget_set_sensitive (GTK_WIDGET (button_delete), FALSE);
 
 
+#ifdef GNOME1
   button_exit = gnome_stock_or_ordinary_button ("Close");
+#else
+  button_exit = gtk_button_new_from_stock ("Close");
+#endif
   gtk_box_pack_start (GTK_BOX (hbox1), button_exit, TRUE, TRUE, 0);
   gtk_widget_show (button_exit);
   gtk_signal_connect (GTK_OBJECT (button_exit), "clicked",
