@@ -32,7 +32,7 @@ void cat_selected(GtkWidget *clist, gint row, gint column, GdkEventButton *event
 void cat_unselected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
 gboolean category_count (GNode * gn, gpointer data);
 GList *make_categories_list(FOLDER * racine);
-void remove_unused_categories (FOLDER * racine);
+void remove_unused_categories (FOLDER * racine, gboolean update_gui);
 void edit_categories (FOLDER *racine);
 
 #endif
