@@ -24,6 +24,6 @@
 
 gint compare(const gchar *pattern, const gchar *string, gint regex, gboolean case_sensitive);
 char *convert_string_with_slashes (gchar * s);
-GPtrArray *extract_field (const gchar * string, const gchar * separator, GArray *field);
+GPtrArray *extract_field (const gchar * string, const gchar * separator, GArray *field, int nb_fields);
 
 #endif
