@@ -23,11 +23,22 @@
 #include <gnome.h>
 #include <time.h>
 
+#ifdef GNOME1
+#define G_FILE_TEST_IS_REGULAR G_FILE_TEST_ISFILE
+#define G_CALLBACK(a) a
+#define G_CONST_RETURN
+#ifndef USE_GNOMEVFS
+#define gnome_vfs_get_mime_type(a) gnome_mime_type_from_magic(a)
+#define gnome_vfs_mime_type_from_name_or_default(a,b) gnome_mime_type_or_default(a,b)
+#endif
+#endif
+
+
 #ifdef __DEBUG__
 #include <GML.h>
 #endif
 
-#define GTKTALOGWEB "http://www.freesoftware.fsf.org/gtktalog/"
+#define GTKTALOGWEB "http://www.nongnu.org/gtktalog/"
 
 #define USER_CONFIG_DIR "/.gtktalog"
 #define USER_CONFIG_FILE "gtktalog.cf"
@@ -331,6 +342,10 @@ typedef struct
 
   gboolean display_splash;
 
+  gboolean edit_description_is_recursive;
+  gboolean edit_category_is_recursive;
+
+
   char *fast_name;
   short want_to_exit;
 
