@@ -105,7 +105,7 @@ static void
 ok_clicked (GtkWidget * w, gpointer data)
 {
   FOLDER *racine = data;
-  gchar *entry_text, *entry_text2, *entry_text3;
+  G_CONST_RETURN gchar *entry_text, *entry_text2, *entry_text3;
   GNode *gn;
   FILE_DATA *fd;
   GtkCTreeNode *gtknode;
@@ -132,7 +132,7 @@ ok_clicked (GtkWidget * w, gpointer data)
     {
       static struct _gnode_and_string gns;
       gns.gn = NULL;
-      gns.s = entry_text;
+      gns.s = (gchar *) entry_text;
 
       g_node_traverse (gn->parent, G_POST_ORDER, G_TRAVERSE_ALL, 2,
 		       is_file_with_the_same_name, &gns);
@@ -147,18 +147,22 @@ ok_clicked (GtkWidget * w, gpointer data)
 
   /* Change the category */
   if (gtk_toggle_button_get_active
-      (GTK_TOGGLE_BUTTON (widget_is_category_empty)) == TRUE)
-
+      (GTK_TOGGLE_BUTTON (widget_is_category_empty)))
     {
-      fd->categorie = string_to_index (racine->categories, entry_text2);
+      fd->categorie =
+	string_to_index (racine->categories, (gchar *) entry_text2);
     }
   else
     fd->categorie = 0;
+
+  my_config->edit_category_is_recursive = FALSE;
+
   if ((is_file (racine->selected_folder) == FALSE)
       && (is_link (racine->selected_folder) == FALSE))
     {
+      my_config->edit_category_is_recursive = TRUE;
       if (gtk_toggle_button_get_active
-	  (GTK_TOGGLE_BUTTON (recursive_category)) == TRUE)
+	  (GTK_TOGGLE_BUTTON (recursive_category)))
 	{
 	  g_node_traverse (gn, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 			   _change_category,
@@ -169,27 +173,32 @@ ok_clicked (GtkWidget * w, gpointer data)
   /* Change the descriptions ? */
   gc_descriptions_flag = FALSE;
   if (gtk_toggle_button_get_active
-      (GTK_TOGGLE_BUTTON (widget_is_description_empty)) == TRUE)
+      (GTK_TOGGLE_BUTTON (widget_is_description_empty)))
     {
-      fd->description = description_add (racine->descriptions, entry_text3);
+      fd->description =
+	description_add (racine->descriptions, (gchar *) entry_text3);
     }
   else
     {
       fd->description = 0;
       gc_descriptions_flag = TRUE;
     }
+
+  my_config->edit_description_is_recursive = FALSE;
+
   if ((is_file (racine->selected_folder) == FALSE)
       && (is_link (racine->selected_folder) == FALSE))
     {
+      my_config->edit_description_is_recursive = TRUE;
       if (gtk_toggle_button_get_active
-	  (GTK_TOGGLE_BUTTON (recursive_description)) == TRUE)
+	  (GTK_TOGGLE_BUTTON (recursive_description)))
 	{
 	  g_node_traverse (gn, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 			   _change_description,
 			   GUINT_TO_POINTER (0 + fd->description));
 	}
     }
-  if (gc_descriptions_flag == TRUE)
+  if (gc_descriptions_flag)
     description_garbage_collection ();
 
 
@@ -198,8 +207,7 @@ ok_clicked (GtkWidget * w, gpointer data)
     {
       g_string_free (fd->name, TRUE);
       fd->name = g_string_new (entry_text);
-      if ((is_dir (gn) == TRUE) || (is_disk (gn) == TRUE)
-	  || (is_vfs_any (gn) == TRUE))
+      if ((is_dir (gn)) || (is_disk (gn)) || (is_vfs_any (gn)))
 	{
 	  gtknode = fd->ctree_node;
 	  if (g_node_depth (gn) == 2)
@@ -314,7 +322,7 @@ _edit_categories (GtkWidget * w, FOLDER * racine)
 void
 desc_sw_clicked (GtkWidget * w, gpointer data)
 {
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)) == TRUE)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
     {
       gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
     }
@@ -354,36 +362,36 @@ edit_folder (GtkWidget * w, FOLDER * racine)
 				    GTK_WINDOW (main_window));
 
       gtk_window_set_position (GTK_WINDOW (edit_window), GTK_WIN_POS_MOUSE);
-      if ((is_file (racine->selected_folder) == TRUE)
-	  || (is_link (racine->selected_folder) == TRUE))
+      if ((is_file (racine->selected_folder))
+	  || (is_link (racine->selected_folder)))
 	gtk_widget_set_usize (GTK_WIDGET (edit_window), 300, 170);
       else
 	gtk_widget_set_usize (GTK_WIDGET (edit_window), 300, 210);
-      if (is_disk (racine->selected_folder) == TRUE)
+      if (is_disk (racine->selected_folder))
 	{
 	  gtk_window_set_title (GTK_WINDOW (edit_window), _("Edit disk"));
 	  gtk_window_set_wmclass (GTK_WINDOW (edit_window), _("Edit disk"),
 				  "GTKtalog");
 	}
-      else if (is_vfs_any (racine->selected_folder) == TRUE)
+      else if (is_vfs_any (racine->selected_folder))
 	{
 	  gtk_window_set_title (GTK_WINDOW (edit_window), _("Edit vfs"));
 	  gtk_window_set_wmclass (GTK_WINDOW (edit_window), _("Edit vfs"),
 				  "GTKtalog");
 	}
-      else if (is_link (racine->selected_folder) == TRUE)
+      else if (is_link (racine->selected_folder))
 	{
 	  gtk_window_set_title (GTK_WINDOW (edit_window), _("Edit link"));
 	  gtk_window_set_wmclass (GTK_WINDOW (edit_window), _("Edit link"),
 				  "GTKtalog");
 	}
-      else if (is_dir (racine->selected_folder) == TRUE)
+      else if (is_dir (racine->selected_folder))
 	{
 	  gtk_window_set_title (GTK_WINDOW (edit_window), _("Edit folder"));
 	  gtk_window_set_wmclass (GTK_WINDOW (edit_window), _("Edit folder"),
 				  "GTKtalog");
 	}
-      else if (is_file (racine->selected_folder) == TRUE)
+      else if (is_file (racine->selected_folder))
 	{
 	  gtk_window_set_title (GTK_WINDOW (edit_window), _("Edit file"));
 	  gtk_window_set_wmclass (GTK_WINDOW (edit_window), _("Edit file"),
@@ -392,7 +400,7 @@ edit_folder (GtkWidget * w, FOLDER * racine)
       gtk_window_set_policy (GTK_WINDOW (edit_window), TRUE, TRUE, TRUE);
       gtk_container_border_width (GTK_CONTAINER (edit_window), 10);
       gtk_signal_connect (GTK_OBJECT (edit_window),
-			  "delete_event", destroy_window, NULL);
+			  "delete_event", G_CALLBACK (destroy_window), NULL);
 
       vbox = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (edit_window), vbox);
@@ -401,15 +409,15 @@ edit_folder (GtkWidget * w, FOLDER * racine)
       /* First frame (edit label) */
       frame = gtk_frame_new (NULL);
       gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
-      if (is_disk (racine->selected_folder) == TRUE)
+      if (is_disk (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Edit disk label"));
-      else if (is_vfs_any (racine->selected_folder) == TRUE)
+      else if (is_vfs_any (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Vfs label"));
-      else if (is_link (racine->selected_folder) == TRUE)
+      else if (is_link (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Link label"));
-      else if (is_dir (racine->selected_folder) == TRUE)
+      else if (is_dir (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Directory label"));
-      else if (is_file (racine->selected_folder) == TRUE)
+      else if (is_file (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("File label"));
       gtk_frame_set_label_align (GTK_FRAME (frame), 0.0, 0.0);
       gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_OUT);
@@ -428,16 +436,16 @@ edit_folder (GtkWidget * w, FOLDER * racine)
       /* Second entry (category combo box) */
       frame = gtk_frame_new (NULL);
       gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
-      if (is_disk (racine->selected_folder) == TRUE)
+      if (is_disk (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Change disk category"));
-      else if (is_vfs (racine->selected_folder) == TRUE)
+      else if (is_vfs (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Change vfs category"));
-      else if (is_link (racine->selected_folder) == TRUE)
+      else if (is_link (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Change link category"));
-      else if (is_dir (racine->selected_folder) == TRUE)
+      else if (is_dir (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame),
 			     _("Change directory category"));
-      else if (is_file (racine->selected_folder) == TRUE)
+      else if (is_file (racine->selected_folder))
 	gtk_frame_set_label (GTK_FRAME (frame), _("Change file category"));
       gtk_frame_set_label_align (GTK_FRAME (frame), 0.0, 0.0);
       gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_OUT);
@@ -583,17 +591,21 @@ edit_folder (GtkWidget * w, FOLDER * racine)
 	  recursive_category =
 	    gtk_check_button_new_with_label (_("Category"));
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-					(recursive_category), FALSE);
-	  gtk_box_pack_start (GTK_BOX (the_box), recursive_category,
-			      FALSE, TRUE, 0);
+					(recursive_category),
+					my_config->
+					edit_category_is_recursive);
+	  gtk_box_pack_start (GTK_BOX (the_box), recursive_category, FALSE,
+			      TRUE, 0);
 	  gtk_widget_show (recursive_category);
 
 	  recursive_description =
 	    gtk_check_button_new_with_label (_("Description"));
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-					(recursive_description), FALSE);
-	  gtk_box_pack_start (GTK_BOX (the_box), recursive_description,
-			      FALSE, TRUE, 0);
+					(recursive_description),
+					my_config->
+					edit_description_is_recursive);
+	  gtk_box_pack_start (GTK_BOX (the_box), recursive_description, FALSE,
+			      TRUE, 0);
 	  gtk_widget_show (recursive_description);
 	}
 
@@ -602,7 +614,11 @@ edit_folder (GtkWidget * w, FOLDER * racine)
       gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
       gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbox), 5);
 
+#ifdef GNOME1
       ok = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
+#else
+      ok = gtk_button_new_from_stock (GNOME_STOCK_BUTTON_OK);
+#endif
       GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
       gtk_window_set_default (GTK_WINDOW (edit_window), ok);
       gtk_box_pack_start (GTK_BOX (hbox), ok, TRUE, TRUE, 0);
@@ -610,11 +626,15 @@ edit_folder (GtkWidget * w, FOLDER * racine)
 			  GTK_SIGNAL_FUNC (ok_clicked), racine);
       gtk_widget_show (ok);
 
+#ifdef GNOME1
       cancel = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
+#else
+      cancel = gtk_button_new_from_stock (GNOME_STOCK_BUTTON_CANCEL);
+#endif
       GTK_WIDGET_SET_FLAGS (cancel, GTK_CAN_DEFAULT);
       gtk_box_pack_start (GTK_BOX (hbox), cancel, TRUE, TRUE, 0);
-      gtk_signal_connect (GTK_OBJECT (cancel), "clicked", cancel_clicked,
-			  NULL);
+      gtk_signal_connect (GTK_OBJECT (cancel), "clicked",
+			  G_CALLBACK (cancel_clicked), NULL);
       gtk_widget_show (cancel);
 
       gtk_widget_add_accelerator (cancel, "clicked", accel_group,
