@@ -16,16 +16,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef HMMM_DES_DONUTS_H__
-#define HMMM_DES_DONUTS_H__
+#ifndef __EDIT_H__
+#define __EDIT_H__
 
-void edit_folder(GtkWidget *w);
-void list_folder(Folder *folder);
-void update_cat_box();
-void delete_folder(GtkWidget *w);
-int file_exist_in(Folder *folder, char *name, GtkWidget *widget);
-int folder_exist_in(Folder *folder, char *name, GtkWidget *widget);
+#include "config_common.h"
+
+gboolean is_file_with_the_same_name(GNode *gn, gpointer data);
+gboolean _change_category(GNode *gn, gpointer data);
+gboolean _change_description(GNode *gn, gpointer data);
+gint description_add(GPtrArray *description_array, gchar *text);
+void update_category_combo (FOLDER *racine);
+void delete_folder (GtkWidget * w, FOLDER * racine);
+void edit_folder(GtkWidget *w, FOLDER * racine);
+void update_disk(GtkWidget *w, FOLDER * racine);
 
 
 #endif
-
