@@ -24,6 +24,9 @@
 #include "config_common.h"
 #include "exit.h"
 #include "setup.h"
+#include "io.h"
+#include "interface.h"
+#include "thread_utils.h"
 
 gint
 yes_no_cancel_dialog (gchar * title, gchar * message)
@@ -68,15 +71,28 @@ void
 quit_prog (FOLDER * racine)
 {
   gboolean quit_anyway = TRUE;
-
+  gint ynd = 0;
   if (racine)
     {
       if (racine->is_modified == TRUE)
 	{
-	  if (yes_no_cancel_dialog (_("Exit dialog"),
-				    _
-				    ("The catalog has not been saved. Leave anyway?"))
-	      != 0)
+	  ynd = yes_no_cancel_dialog (_("Exit dialog"),
+				      _
+				      ("The catalog has not been saved. Save before exit?"));
+	  if (ynd == 0)
+	    {
+	      fast_save (my_config->racine);
+	      my_config->want_to_exit = WANT_TO_EXIT_SAVING;
+	      while (my_config->want_to_exit == WANT_TO_EXIT_SAVING)
+		{
+		  while (gtk_events_pending ())
+		    gtk_main_iteration ();
+		}
+	      if (my_config->want_to_exit == WANT_TO_EXIT_CANCELLED)
+		quit_anyway = FALSE;
+
+	    }
+	  else if (ynd == 2)
 	    {
 
 	      quit_anyway = FALSE;
@@ -87,6 +103,7 @@ quit_prog (FOLDER * racine)
     {
       gdk_window_get_size (main_window->window, &(my_config->mainwindow_w),
 			   &(my_config->mainwindow_h));
+      save_ctree_window_size ();
       gdk_window_get_root_origin (main_window->window,
 				  &(my_config->mainwindow_x),
 				  &(my_config->mainwindow_y));
