@@ -16,14 +16,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef YOU_WANT_ME_TO_GO_BACK_TO_MY_PLANE_AND_GO_BACK_TO_FRANCE_H__
-#define YOU_WANT_ME_TO_GO_BACK_TO_MY_PLANE_AND_GO_BACK_TO_FRANCE_H__
+#ifndef __EXIT_H__
+#define __EXIT_H__
 
-#include <gtk/gtk.h>
-
-void exit_dialog(GtkWidget *widget, gpointer data);
+#include <config.h>
+#include <gnome.h>
+#include "config_common.h"
 
+gint yes_no_cancel_dialog (gchar * title, gchar * message);
+gint yes_no_dialog (gchar * title, gchar * message);
+void quit_prog (FOLDER * racine);
 
 #endif
-
-
