@@ -219,7 +219,7 @@ fad_create_window (gchar ** fast_name, FOLDER * racine)
 	}
       else if (button == 0)
 	{
-	  gchar *temp;
+	  G_CONST_RETURN gchar *temp;
 
 	  /* Get the name of the CD */
 	  temp = gtk_entry_get_text (GTK_ENTRY (name_entry));
@@ -238,7 +238,7 @@ fad_create_window (gchar ** fast_name, FOLDER * racine)
 				      _("Disk name should not be blank"));
 		}
 	    }
-	  else if (is_disk_name_unique (racine, temp))
+	  else if (is_disk_name_unique (racine, (gchar *) temp))
 	    {
 	      name_ok = TRUE;
 
@@ -312,7 +312,6 @@ fast_add_disk (FOLDER * racine)
 #else
   set_local_folder_name (my_config->mount_point->str);
 #endif
-
   set_thread_status_to_running ();
   init_vfs_scan_status ();
   set_added_disk (ADDED_DISK_UNDEF);
@@ -371,9 +370,10 @@ start_add_cd_for_update (char *foldername, char *diskname, FOLDER * racine)
 
   do_not_forget_to_mount (FALSE);
   set_thread_status_to_running ();
-  progress_createTimeout (GINT_TO_POINTER (GNOMEAPPBAR_MAIN));
+//  progress_createTimeout (GINT_TO_POINTER (GNOMEAPPBAR_MAIN));
   do_not_forget_to_umount (TRUE);
   init_vfs_scan_status ();
+  set_added_disk (ADDED_DISK_UNDEF);
 #if defined(USE_PTHREADS)
   if (pthread_create (&thread1, NULL, start_thread_scan, racine) < 0)
     {
