@@ -18,6 +18,9 @@
 
 #include <config.h>
 #include <gnome.h>
+#ifdef USE_GNOMEVFS
+#include <libgnomevfs/gnome-vfs-mime.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -345,7 +348,11 @@ folder_get_mime (GNode * gn)
   fd = get_file_data_from_gnode (gn);
   if (fd->mime)
     return (fd->mime->str);
+#ifdef USE_GNOMEVFS
+  return (gnome_vfs_mime_type_from_name_or_default (fd->name->str, NULL));
+#else
   return (gnome_mime_type_or_default (fd->name->str, NULL));
+#endif
 }
 
 const char *
