@@ -25,6 +25,10 @@
 #    include <sys/mount.h>
 #endif
 #include <gnome.h>
+#ifdef USE_GNOMEVFS
+#include <libgnomevfs/gnome-vfs-mime-info.h>
+//#include <libbonobo.h>
+#endif
 #include <strings.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -50,6 +54,9 @@ static GtkWidget *ctree_window;
 static GtkWidget *clist_window;
 static GtkWidget *hpaned;
 static GtkWidget *vbox_containing_ctree;
+#ifdef GNOME1
+static GtkWidget *infotext;	/* HY hack: add a text in main window showing file info */
+#endif
 
 static GNode *current_displayed_gnode = NULL;
 static gboolean current_displayed_gnode_expand_tree;
@@ -246,6 +253,66 @@ viewer_command_line (gchar * filename, const gchar * command)
   return (retour);
 }
 
+#ifdef GNOME1
+/* HY hacks, use a dialog with text widget to show information,
+ * (origally it's displayed via a message box)*/
+void
+show_file_info (const GtkWindow * parent, const gchar * filename,
+		const gchar * info)
+{
+  GString *caption;
+  GtkWidget *infodialog, *infotext, *hbox;
+  GtkWidget *vscrollbar, *label;
+
+  /* make sure the dialog is 100-chars in wide */
+  caption = g_string_new (filename);
+  g_string_sprintf (caption, "%-100s", filename);
+
+  infodialog = gnome_dialog_new (_("File information"),
+				 GNOME_STOCK_BUTTON_OK,
+				 GNOME_STOCK_BUTTON_CANCEL, NULL);
+  gnome_dialog_set_parent (GNOME_DIALOG (infodialog), GTK_WINDOW (parent));
+/*    gtk_signal_connect(GTK_OBJECT(infodialog), "destroy", 
+        GTK_SIGNAL_FUNC(fileinfo_dialog_closed), &infodialog); */
+
+  label = gtk_label_new (caption->str);
+  g_string_free (caption, TRUE);
+
+
+  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (infodialog)->vbox), label,
+		      TRUE, TRUE, 0);
+  gtk_widget_show (label);
+
+  hbox = gtk_hbox_new (FALSE, 5);
+  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (infodialog)->vbox), hbox,
+		      TRUE, TRUE, 0);
+
+  infotext = gtk_text_new (NULL, NULL);
+
+  vscrollbar = gtk_vscrollbar_new (GTK_TEXT (infotext)->vadj);
+
+  gtk_box_pack_start (GTK_BOX (hbox), infotext, TRUE, TRUE, 0);
+  gtk_text_set_editable (GTK_TEXT (infotext), TRUE);
+  gtk_text_set_word_wrap (GTK_TEXT (infotext), FALSE);
+
+  /* void gtk_text_insert( GtkText *text, GdkFont *font, GdkColor *fore, 
+     GdkColor *back, const char *chars, gint length );
+   */
+/*    gnome_dialog_close_hides(GNOME_DIALOG(infodialog), TRUE); */
+  gtk_box_pack_start (GTK_BOX (hbox), vscrollbar, FALSE, FALSE, 0);
+  gtk_widget_show (vscrollbar);
+  gtk_widget_show (infotext);
+  gtk_widget_show (hbox);
+
+  gtk_editable_delete_text (GTK_EDITABLE (infotext), 0, -1);
+  gtk_text_insert (GTK_TEXT (infotext), NULL, NULL, NULL, info, -1);
+  /*gdk_window_resize(infodialog->window, 320, 240); */
+  gnome_dialog_run (GNOME_DIALOG (infodialog));
+
+  gnome_dialog_close (GNOME_DIALOG (infodialog));
+}
+#endif
+
 void
 launch_viewer (GNode * gn, gint row)
 {
@@ -331,14 +398,19 @@ launch_viewer (GNode * gn, gint row)
       if ((my_config->dbclick_opens_info)
 	  && ((info = folder_get_informations (gn))))
 	{
+#ifndef GNOME1
 	  gnome_dialog_run_and_close (GNOME_DIALOG
 				      (gnome_ok_dialog_parented
 				       (info, GTK_WINDOW (main_window))));
+#else
+	  fullname = get_real_path_from_node (gn);
+	  show_file_info (GTK_WINDOW (main_window), fullname->str, info);
+#endif
 	}
       else
 	{
 	  fullname = get_real_path_from_node (gn);
-	  if (!g_file_test (fullname->str, G_FILE_TEST_ISFILE))
+	  if (!g_file_test (fullname->str, G_FILE_TEST_IS_REGULAR))
 	    {
 	      ERROR_DIALOG (_
 			    ("The file does not exist.\nMaybe it was removed or it is on a CD.\nIn this case, load the CD, mount it and try again"),
@@ -355,7 +427,11 @@ launch_viewer (GNode * gn, gint row)
 
 	      if (mime)
 		{
+#ifdef USE_GNOMEVFS
+		  viewer = gnome_vfs_mime_get_value (mime, "view");
+#else
 		  viewer = gnome_mime_get_value (mime, "view");
+#endif
 		  if (viewer)
 		    {
 		      command_line =
@@ -406,13 +482,27 @@ launch_viewer (GNode * gn, gint row)
 		      if (!compare ("^text/.*", mime, COMPARE_REGEX, TRUE))
 			{
 			  GtkWidget *dialog, *gl;
-
+#ifndef GNOME1
+			  GtkTextBuffer *buffer;
+			  gchar *stringbuffer;
+#endif
 			  dialog =
 			    gnome_dialog_new (fd->name->str,
 					      GNOME_STOCK_BUTTON_CLOSE, NULL);
+#ifdef GNOME1
 			  gl = gnome_less_new ();
 			  gnome_less_show_file (GNOME_LESS (gl),
 						fullname->str);
+#else
+			  gl = gtk_text_view_new ();
+			  buffer =
+			    gtk_text_view_get_buffer (GTK_TEXT_VIEW (gl));
+			  g_file_get_contents (fullname->str, &stringbuffer,
+					       NULL, NULL);
+			  gtk_text_buffer_set_text (buffer, stringbuffer, -1);
+			  gtk_text_view_set_editable (GTK_TEXT_VIEW (gl),
+						      FALSE);
+#endif
 			  gtk_box_pack_start (GTK_BOX
 					      (GNOME_DIALOG (dialog)->vbox),
 					      gl, TRUE, TRUE, 0);
@@ -907,7 +997,6 @@ list_folder (GNode * parent, gboolean expand_tree)
   current_displayed_gnode_expand_tree = expand_tree;
   if (current_displayed_gnode == NULL)
     return;
-
   gtk_clist_freeze (GTK_CLIST (clist));
   gtk_clist_clear (GTK_CLIST (clist));
   if (g_node_depth (parent) > 1)
@@ -985,7 +1074,7 @@ key_pressed (GtkWidget * wid, GdkEventKey * event, gpointer data)
   if ((event->keyval == GDK_Delete) || (event->keyval == GDK_KP_Delete))
     {
       if (my_config->racine && my_config->racine->selected_folder)
-	delete_folder (wid,my_config->racine);
+	delete_folder (wid, my_config->racine);
     }
 }
 
@@ -997,8 +1086,12 @@ clist_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
   GNode *gn;
   GtkWidget *list_menu;
   FOLDER *racine;
+#ifdef GNOME1
+  FILE_DATA *fd;
+  const gchar *info;
+#endif
 
-  if (event->button == 3)
+  if (event->button == 3 || event->button == 1)
     {
       if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
 	  && (!is_search_running ()))
@@ -1012,6 +1105,23 @@ clist_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
 	      racine = get_catalog_from_gnode (gn);
 	      racine->selected_folder = gn;
 
+#ifdef GNOME1
+	      fd = get_file_data_from_gnode (gn);
+	      if ((fd->a_parent_node_is_vfs == IS_VFS)
+		  || (fd->a_parent_node_is_vfs == IS_VFS_EXTENDED))
+		{
+		  return;
+		}
+	      gtk_editable_delete_text (GTK_EDITABLE (infotext), 0, -1);
+	      if ((info = folder_get_informations (gn)))
+		{
+		  gtk_text_insert (GTK_TEXT (infotext), NULL, NULL, NULL,
+				   info, -1);
+		}
+#endif
+
+  if (event->button == 3)
+  {
 	      if (g_list_length ((GTK_CLIST (wid))->selection) > 1)
 		{
 		  list_menu =
@@ -1042,8 +1152,14 @@ clist_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
 		{
 		  list_menu = gnome_popup_menu_new (tree_pressed_menu_disk);
 		}
+#ifdef GNOME1
 	      gnome_popup_menu_do_popup (list_menu, NULL, NULL, event,
 					 racine);
+#else
+	      gnome_popup_menu_do_popup (list_menu, NULL, NULL, event,
+					 racine, NULL);
+#endif
+  }
 	    }
 	}
     }
@@ -1083,59 +1199,18 @@ create_list ()
 }
 
 void
-tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
+tree_selected(GtkWidget * clist, gint row, gint column,
+            GdkEventButton * event, gpointer data)
 {
-  GtkWidget *list_menu;
-  FOLDER *racine = data;
-  GString *tmp;
-  gint row, column;
-  gint x, y;
   GNode *gn, *gntmp;
+  FOLDER *racine;
   FILE_DATA *fd, *tmpfd;
+  GString *tmp;
 
-  if (event->button == 3)
+  if ((event->button == 1))
     {
-      if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
-	  && (!is_search_running ()))
 	{
-	  x = event->x;
-	  y = event->y;
-	  if (gtk_clist_get_selection_info
-	      (GTK_CLIST (wid), x, y, &row, &column))
-	    {
-	      gn = gtk_clist_get_row_data (GTK_CLIST (wid), row);
-	      racine = get_catalog_from_gnode (gn);
-	      racine->selected_folder = gn;
-
-	      if (is_dir (gn) == TRUE)
-		{
-		  list_menu = gnome_popup_menu_new (tree_pressed_menu_dir);
-
-		}
-	      else if (is_link (gn) == TRUE)
-		{
-		  list_menu = gnome_popup_menu_new (tree_pressed_menu_link);
-		}
-	      else if (is_vfs_any (gn) == TRUE)
-		{
-		  list_menu = gnome_popup_menu_new (tree_pressed_menu_vfs);
-		}
-	      else
-		{
-		  list_menu = gnome_popup_menu_new (tree_pressed_menu_disk);
-		}
-	      gnome_popup_menu_do_popup (list_menu, NULL, NULL, event,
-					 racine);
-	    }
-	}
-    }
-  else if ((event->button == 1))
-    {
-      x = event->x;
-      y = event->y;
-      if (gtk_clist_get_selection_info (GTK_CLIST (wid), x, y, &row, &column))
-	{
-	  gn = gtk_clist_get_row_data (GTK_CLIST (wid), row);
+	  gn = gtk_clist_get_row_data (GTK_CLIST (clist), row);
 	  racine = get_catalog_from_gnode (gn);
 	  if (G_NODE_IS_ROOT (gn) != TRUE)
 	    {
@@ -1183,6 +1258,60 @@ tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
 }
 
 
+void
+tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
+{
+  GtkWidget *list_menu;
+  FOLDER *racine = data;
+  gint row, column;
+  gint x, y;
+  GNode *gn;
+
+  if (event->button == 3)
+    {
+      if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
+	  && (!is_search_running ()))
+	{
+	  x = event->x;
+	  y = event->y;
+	  if (gtk_clist_get_selection_info
+	      (GTK_CLIST (wid), x, y, &row, &column))
+	    {
+	      gn = gtk_clist_get_row_data (GTK_CLIST (wid), row);
+	      racine = get_catalog_from_gnode (gn);
+	      racine->selected_folder = gn;
+
+	      if (is_dir (gn) == TRUE)
+		{
+		  list_menu = gnome_popup_menu_new (tree_pressed_menu_dir);
+
+		}
+	      else if (is_link (gn) == TRUE)
+		{
+		  list_menu = gnome_popup_menu_new (tree_pressed_menu_link);
+		}
+	      else if (is_vfs_any (gn) == TRUE)
+		{
+		  list_menu = gnome_popup_menu_new (tree_pressed_menu_vfs);
+		}
+	      else
+		{
+		  list_menu = gnome_popup_menu_new (tree_pressed_menu_disk);
+		}
+#ifdef GNOME1
+	      gnome_popup_menu_do_popup (list_menu, NULL, NULL, event,
+					 racine);
+#else
+	      gnome_popup_menu_do_popup (list_menu, NULL, NULL, event,
+					 racine, NULL);
+#endif
+	    }
+	}
+    }
+
+}
+
+
 void
 update_tree (FOLDER * racine)
 {
@@ -1491,6 +1620,10 @@ void
 build_gui (void)
 {
   GtkWidget *appbar1;
+#ifdef GNOME1
+  GtkWidget *vpaned;
+  GtkWidget *sclwin;
+#endif
 
 /* Main vertical box */
   vbox_containing_ctree = gtk_vbox_new (FALSE, 1);
@@ -1530,14 +1663,46 @@ build_gui (void)
 /* Horizontal pan for the tree and file display */
   hpaned = gtk_hpaned_new ();
   gtk_container_add (GTK_CONTAINER (vbox_containing_ctree), hpaned);
+#ifdef GNOME1
   gtk_paned_set_handle_size (GTK_PANED (hpaned), 10);
   gtk_paned_set_gutter_size (GTK_PANED (hpaned), 10);
+#endif
   gtk_widget_show (hpaned);
 
+
+#ifdef GNOME1
+  /* --- HY hack ------------- */
+  vpaned = gtk_vpaned_new ();
+  gtk_paned_add2 (GTK_PANED (hpaned), vpaned);
+  gtk_paned_set_handle_size (GTK_PANED (vpaned), 10);
+  gtk_paned_set_gutter_size (GTK_PANED (vpaned), 10);
+  sclwin = gtk_scrolled_window_new (NULL, NULL);
+
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sclwin),
+				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  infotext = gtk_text_new (NULL, NULL);
+  gtk_container_add (GTK_CONTAINER (sclwin), infotext);
+
+  gtk_widget_show (infotext);
+  gtk_widget_set_usize (sclwin, -1, 30);
+  gtk_widget_show (sclwin);
+  gtk_paned_add2 (GTK_PANED (vpaned), sclwin);
+
+  gtk_widget_show (vpaned);
+  /* =============           */
+
 /* Clist window to display the files */
   clist_window = create_list ();
-  gtk_paned_add2 (GTK_PANED (hpaned), clist_window);
+  gtk_widget_set_usize (clist_window, -1, 250);
+  gtk_paned_add1 (GTK_PANED (vpaned), clist_window);
   gtk_widget_show (clist_window);
+#else
+  clist_window = create_list ();
+  gtk_paned_add2 (GTK_PANED (hpaned), clist_window);
+#endif
+
+
+
 
 /* CTtree window to display the directory tree */
   ctree_window = gtk_scrolled_window_new (NULL, NULL);
@@ -1547,7 +1712,11 @@ build_gui (void)
     gtk_widget_set_usize (ctree_window, my_config->ctreewindow_w,
 			  my_config->ctreewindow_h);
   else
+#ifdef GNOME1
+    gtk_widget_set_usize (ctree_window, 150, 300);
+#else
     gtk_widget_set_usize (ctree_window, 150, 150);
+#endif
 
   gtk_widget_show (ctree_window);
 
