@@ -1,20 +1,26 @@
-/*
- * GTKtalog. *  Copyright (C) 1999-2000  Mathieu VILLEGAS * *  This program
- * is free software; you can redistribute it and/or modify *  it under the
- * terms of the GNU General Public License as published by *  the Free
- * Software Foundation; either version 2 of the License, or *  (at your
- * option) any later version. * *  This program is distributed in the hope
- * that it will be useful, *  but WITHOUT ANY WARRANTY; without even the
- * implied warranty of *  MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.  See the *  GNU General Public License for more details. * *  You 
- * should have received a copy of the GNU General Public License *  along
- * with this program; if not, write to the Free Software *  Foundation, Inc., 
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
+/*  GTKtalog.
+ *  Copyright (C) 1999-2000  Mathieu VILLEGAS
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include <config.h>
 #include <gnome.h>
-
+#ifdef USE_GNOMEVFS
+#include <libgnomevfs/gnome-vfs-mime.h>
+#endif
 #include "config_common.h"
 #include "interface.h"
 #include "loadcat.h"
@@ -47,7 +53,13 @@ get_pix_from_gnode (GNode * gn)
       if (fd->mime)
 	mime = g_strdup (fd->mime->str);
       if (!mime)
+#ifdef USE_GNOMEVFS
+	mime =
+	  g_strdup (gnome_vfs_mime_type_from_name_or_default
+		    (fd->name->str, NULL));
+#else
 	mime = g_strdup (gnome_mime_type_or_default (fd->name->str, NULL));
+#endif
       if (mime)
 	{
 	  pix = ((PIX *) g_tree_lookup (my_config->mime_icons, mime));
@@ -234,6 +246,9 @@ create_tree (FOLDER * racine)
   gtk_signal_connect (GTK_OBJECT (racine->ctree), "button_press_event",
 		      GTK_SIGNAL_FUNC (tree_pressed), racine);
 
+  gtk_signal_connect (GTK_OBJECT (racine->ctree), "select_row",
+		      GTK_SIGNAL_FUNC (tree_selected), racine);
+
   racine->ctree_tree_expand_signal_id =
     gtk_signal_connect_after (GTK_OBJECT (racine->ctree), "tree_expand",
 			      GTK_SIGNAL_FUNC (expand_cb), racine);
@@ -476,14 +491,15 @@ merge_cat (FOLDER * racine)
 void
 save_cat_ok_sel (GtkWidget * w, FOLDER * racine)
 {
-  gchar *s, *p;
+  G_CONST_RETURN gchar *s;
+  gchar *p;
   s = gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs));
   if (!strcmp ("", s))
     {
       WARNING_DIALOG (_("Please specify a file name."), main_window);
       return;
     }
-  if (g_file_test (s, G_FILE_TEST_ISDIR))
+  if (g_file_test (s, G_FILE_TEST_IS_REGULAR))
     {
       WARNING_DIALOG (_
 		      ("Either you did not specify a file name or the file is already existing as a directory\n"
@@ -494,7 +510,7 @@ save_cat_ok_sel (GtkWidget * w, FOLDER * racine)
   my_config->save_only_used_categories =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggle_save_cat_mode));
   racine->catalog_filename_is_valid = FALSE;
-  if (save_cat_to_file (s, racine) == 0)
+  if (save_cat_to_file ((gchar *) s, racine) == 0)
     {
       gtk_window_set_title (GTK_WINDOW (main_window),
 			    racine->catalog_filename->str);
@@ -587,8 +603,8 @@ fast_save (FOLDER * racine)
 gint
 autosave (gpointer data)
 {
-  if ((my_config->racine->is_modified) && my_config->autosave
-      && my_config->racine->catalog_filename_is_valid)
+  if (my_config->racine && my_config->racine->is_modified
+      && my_config->autosave && my_config->racine->catalog_filename_is_valid)
     {
       if ((get_thread_status () == THREAD_SCAN_RUNNING_NO)
 	  && (!is_search_running ()) && (!is_saving ()))
@@ -635,19 +651,20 @@ test_plugin_existence (GString * filename)
   gchar **paths, **p1;
   gchar *fullname = NULL;
   int i;
-  
+
   if (filename->str[0] == '/')
-    return (g_file_test (filename->str, G_FILE_TEST_ISFILE));
+    return (g_file_test (filename->str, G_FILE_TEST_IS_REGULAR));
   path = getenv ("PATH");
   paths = g_strsplit (path, ":", 0);
   p1 = paths;
   while (*p1)
     {
       fullname = g_strconcat (*p1, "/", filename->str, NULL);
-      for(i=0; (fullname[i] != '\0') && (fullname[i] != ' ') && (fullname[i] !=
-      '\t'); i++);
+      for (i = 0;
+	   (fullname[i] != '\0') && (fullname[i] != ' ')
+	   && (fullname[i] != '\t'); i++);
       fullname[i] = '\0';
-      if (g_file_test (fullname, G_FILE_TEST_ISFILE))
+      if (g_file_test (fullname, G_FILE_TEST_IS_REGULAR))
 	break;
       g_free (fullname);
       fullname = NULL;
