@@ -27,6 +27,7 @@
 PIX *get_pix_from_gnode (GNode * gn);
 gboolean add_gnode_to_ctree (GNode * gn, gpointer data);
 void open_cat_ok_sel(GtkWidget *w, gpointer data);
+void merge_cat (FOLDER *racine);
 void open_cat (FOLDER *racine);
 void expand_folder (GNode * gn);
 void create_tree(FOLDER *racine);
@@ -34,6 +35,7 @@ void new_file();
 void save_cat_ok_sel(GtkWidget *w, FOLDER *racine);
 void save_cat(FOLDER *racine);
 void fast_save(FOLDER *racine);
+gint autosave (gpointer data);
 const gint string_to_index(GPtrArray *a, gchar *s);
 gboolean test_plugin_existence(GString *filename);
 
