@@ -380,7 +380,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
   error_status = 0;
 
 /* Test if the file exists */
-  if ((g_file_test (filename, G_FILE_TEST_ISFILE)) != TRUE)
+  if ((g_file_test (filename, G_FILE_TEST_IS_REGULAR)) != TRUE)
     {
       ERROR_DIALOG (_("File does not exist or is not a standard file"),
 		    main_window);
@@ -419,7 +419,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
       if (merge)
 	{
 	  ERROR_DIALOG (_
-			("You can only merge catalogs generated with gtktalog version >= 0.10.1"),
+			("You can only merge catalogs generated with GTKtalog version >= 0.10.1"),
 			main_window);
 	  return (-1);
 	}
@@ -433,7 +433,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
 	  WARNING_DIALOG (_
 			  ("Warning: You are trying to load an a catalog saved in an old format.\n"
 			   "This will work now, but the code for loading an old catalog will not be maintained.\n"
-			   "It should not stay in gtktalog for a long time, "
+			   "It should not stay in GTKtalog for a long time, "
 			   "so do not forget to save your converted catalogs.\n"
 			   "However, a converter exists and will be maintained in case "
 			   "you had forgotten to convert a catalog"),
@@ -459,7 +459,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
 	  ERROR_DIALOG (_
 			("File seems to have been generated with a version older "
 			 "than 0.1.0 of GTKtalog. Formats are incompatible.\n"
-			 "Try `./configure --enable-catalog2' then recompile gtktalog. "
+			 "Try `./configure --enable-catalog2' then recompile GTKtalog. "
 			 "Or use the converter!"), main_window);
 	  return (-1);
 
@@ -501,7 +501,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
       if (merge)
 	{
 	  ERROR_DIALOG (_
-			("You can only merge catalogs generated with gtktalog version >= 0.10.1"),
+			("You can only merge catalogs generated with GTKtalog version >= 0.10.1"),
 			main_window);
 	  return (-1);
 	}
@@ -512,7 +512,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
 	  WARNING_DIALOG (_
 			  ("Warning: You are trying to load an a catalog saved in an old format.\n"
 			   "This will work now, but the code for loading an old catalog will not be maintained.\n"
-			   "It should not stay in gtktalog for a long time, "
+			   "It should not stay in GTKtalog for a long time, "
 			   "so do not forget to save your converted catalogs."),
 			  main_window);
 #else
@@ -521,7 +521,7 @@ load_all_from_file (char *filename, FOLDER * racine, gboolean all,
 	  ERROR_DIALOG (_
 			("File seems to have been generated with a version older "
 			 "than 0.10.1 of GTKtalog. Formats are incompatibles.\n"
-			 "Try `./configure --enable-catalog3' then recompile gtktalog "),
+			 "Try `./configure --enable-catalog3' then recompile GTKtalog "),
 			main_window);
 	  return (-1);
 #endif
