@@ -22,15 +22,20 @@
 #include "config_common.h"
 
 #ifdef CATALOG2
-	#include "load_oldcat.h"
+#include "load_oldcat.h"
 #endif
 
-GString *read_gstring(gzFile fh);
-FILE_DATA *read_filedata(gzFile gzfh);
-void load_folder_tree(FOLDER *racine, gzFile gzcatalog);
-GPtrArray *load_gptrarray_of_gstrings(gzFile gzfh);
+GString *read_gstring (gzFile fh);
+FILE_DATA *read_filedata (gzFile gzfh, GTree * desc_merge_table,
+			  GTree * cat_merge_table);
+void load_folder_tree (FOLDER * racine,
+		       gzFile gzcatalogGTree, GTree * desc_merge_table,
+		       GTree * cat_merge_table);
+GPtrArray *load_gptrarray_of_gstrings (gzFile gzfh, GPtrArray * gpa,
+				       GTree * tab);
 gboolean update_vfs_fd (GNode * gn, gpointer data);
-int load_cat_from_file(char *filename, FOLDER *racine);
+int load_cat_from_file (char *filename, FOLDER * racine);
+int merge_cat_from_file (char *filename, FOLDER * racine);
 int load_only_categories_from_file (char *filename, FOLDER * racine);
 
 #endif
