@@ -103,9 +103,12 @@ session_die (GnomeClient * client, gpointer client_data)
 }
 
 int
-main (int argc, char *argv[])
+main (int argc, const char *argv[])
 {
   poptContext optCon;
+#ifndef GNOME1
+  GnomeProgram *gnomeprog;
+#endif
   GString *_title = NULL;
   GString *_filename = NULL;
   GString *_geometry = NULL;
@@ -123,10 +126,20 @@ main (int argc, char *argv[])
 #endif
   cwd = g_get_current_dir ();
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+#ifndef GNOME1
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
   textdomain (PACKAGE);
-  gnome_init_with_popt_table (PACKAGE, VERSION, argc, argv, command_line, 0,
-			      &optCon);
+#ifdef GNOME1
+  gnome_init_with_popt_table (PACKAGE, VERSION, argc, (char **) argv,
+			      command_line, 0, &optCon);
+  optCon = poptGetContext (NULL, argc, (char **) argv, command_line, 0);
+#else
+  gnomeprog =
+    gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc,
+			(gchar **) argv, GNOME_PARAM_POPT_TABLE, NULL, NULL);
   optCon = poptGetContext (NULL, argc, argv, command_line, 0);
+#endif
 
   /* Processing of arguments */
 
@@ -135,7 +148,7 @@ main (int argc, char *argv[])
       switch (c)
 	{
 	case P_VERSION:
-	  printf (_("Gtktalog\nVersion: %s\nLicence: GPL\n"
+	  printf (_("GTKtalog\nVersion: %s\nLicence: GPL\n"
 		    "More infos on " GTKTALOGWEB "\n"), VERSION);
 	  exit (0);
 	  break;
@@ -188,6 +201,7 @@ main (int argc, char *argv[])
 
   if (_geometry)
     {
+#ifdef GNOME1
       if (gnome_parse_geometry (_geometry->str, &wx, &wy, &ww, &wh) != TRUE)
 	{
 	  wx = 0;
@@ -196,6 +210,13 @@ main (int argc, char *argv[])
 	  wh = 350;
 	}
       g_string_free (_geometry, TRUE);
+      _geometry = NULL;
+#else
+      wx = 0;
+      wy = 0;
+      ww = 660;
+      wh = 350;
+#endif
     }
   else
     {
@@ -218,8 +239,7 @@ main (int argc, char *argv[])
   build_gui ();
 
   progress_setGnomeAppBar (NULL, GNOMEAPPBAR_SCAN, FALSE);
-
-  fullname_prog = argv[0];
+  fullname_prog = (char *) argv[0];
   if (!g_path_is_absolute (fullname_prog))
     {
       fullname_prog = g_concat_dir_and_file (cwd, fullname_prog);
@@ -231,11 +251,17 @@ main (int argc, char *argv[])
   gtk_signal_connect (GTK_OBJECT (client), "die",
 		      GTK_SIGNAL_FUNC (session_die), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (main_window), "delete_event", cb_quit_prog,
-		      my_config);
+  gtk_signal_connect (GTK_OBJECT (main_window), "delete_event",
+		      G_CALLBACK (cb_quit_prog), my_config);
 
   gtk_widget_show (main_window);
+#ifdef GNOME1
   if ((my_config->mainwindow_save_xywh) || (_geometry))
+#else
+  if (_geometry)
+    gtk_window_parse_geometry (GTK_WINDOW (main_window), _geometry->str);
+  else if (my_config->mainwindow_save_xywh)
+#endif
     gdk_window_move_resize (main_window->window, wx, wy, ww, wh);
 
   my_config->current_pid = getpid ();
