@@ -35,6 +35,9 @@ static gboolean progress_mode[GNOMEAPPBAR_NB];
 void
 progress_reset ()
 {
+#ifndef GNOME1
+  GtkProgressBar *progress;
+#endif
   gint i;
   progress_INeedReset = FALSE;
   for (i = 0; i < GNOMEAPPBAR_NB; i++)
@@ -57,7 +60,16 @@ progress_reset ()
 	  progress_currentValue[i][0] = 0;
 	  progress_currentValue[i][1] = 0;
 	  if (progress_is_gnome_progress[i])
-	    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[i]), 0);
+	    {
+#ifdef GNOME1
+	      gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[i]),
+					 0);
+#else
+	      progress =
+		gnome_appbar_get_progress (GNOME_APPBAR (progress_appbar[i]));
+	      gtk_progress_set_percentage (GTK_PROGRESS (progress), 0);
+#endif
+	    }
 	  else
 	    gtk_progress_set_percentage (GTK_PROGRESS (progress_appbar[i]),
 					 0);
@@ -122,8 +134,21 @@ progress_timeout (gpointer pstru)
       if ((new_val >= 0) && (new_val < 1.))
 	{
 	  if (progress_is_gnome_progress[reg])
+	    {
+#ifndef GNOME1
+	      GtkProgressBar *progress;
+#endif
+#ifdef GNOME1
 	    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]),
 				       new_val);
+#else
+	      progress =
+		gnome_appbar_get_progress (GNOME_APPBAR
+					   (progress_appbar[reg]));
+	      gtk_progress_set_percentage (GTK_PROGRESS (progress), new_val);
+#endif
+
+	    }
 	  else
 	    gtk_progress_set_percentage (GTK_PROGRESS (progress_appbar[reg]),
 					 new_val);
@@ -131,8 +156,21 @@ progress_timeout (gpointer pstru)
       else
 	{
 	  if (progress_is_gnome_progress[reg])
+	    {
+#ifndef GNOME1
+	      GtkProgressBar *progress;
+#endif
+#ifdef GNOME1
 	    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]),
 				       2. - new_val);
+#else
+	      progress =
+		gnome_appbar_get_progress (GNOME_APPBAR
+					   (progress_appbar[reg]));
+	      gtk_progress_set_percentage (GTK_PROGRESS (progress),
+					   2. - new_val);
+#endif
+	    }
 	  else
 	    gtk_progress_set_percentage (GTK_PROGRESS (progress_appbar[reg]),
 					 2. - new_val);
@@ -146,8 +184,20 @@ progress_timeout (gpointer pstru)
       if (new_val >= 0)
 	{
 	  if (progress_is_gnome_progress[reg])
+	    {
+#ifndef GNOME1
+	      GtkProgressBar *progress;
+#endif
+#ifdef GNOME1
 	    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]),
 				       new_val);
+#else
+	      progress =
+		gnome_appbar_get_progress (GNOME_APPBAR
+					   (progress_appbar[reg]));
+	      gtk_progress_set_percentage (GTK_PROGRESS (progress), new_val);
+#endif
+	    }
 	  else
 	    gtk_progress_set_percentage (GTK_PROGRESS (progress_appbar[reg]),
 					 new_val);
@@ -158,8 +208,20 @@ progress_timeout (gpointer pstru)
 	{
 	  progress_INeedReset = TRUE;
 	  if (progress_is_gnome_progress[reg])
+	    {
+#ifndef GNOME1
+	      GtkProgressBar *progress;
+#endif
+#ifdef GNOME1
 	    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]),
 				       0);
+#else
+	      progress =
+		gnome_appbar_get_progress (GNOME_APPBAR
+					   (progress_appbar[reg]));
+	      gtk_progress_set_percentage (GTK_PROGRESS (progress), 0);
+#endif
+	    }
 	  else
 	    gtk_progress_set_percentage (GTK_PROGRESS (progress_appbar[reg]),
 					 0);
