@@ -27,7 +27,8 @@
 #include "exit.h"
 #include "config_common.h"
 
-static gchar DEFAULT_REPORT[] = "report.out";
+static gchar DEFAULT_REPORT[] = "report";
+static gchar DEFAULT_EXTENSION[] = "txt";
 static gchar ALL_DISKS[] = N_("All disks");
 static gchar ALL_CATEGORIES[] = N_("(All)");
 static gchar CATEGORY_NONE[] = N_("(None)");
@@ -38,6 +39,7 @@ static GtkWidget *check_disks;
 static GtkWidget *check_folders;
 static GtkWidget *check_files;
 static GtkWidget *check_sizes;
+static GtkWidget *check_dates;
 static GtkWidget *check_category;
 static GtkWidget *exclude_vfs;
 static GtkWidget *include_dir_names;
@@ -53,14 +55,20 @@ static GtkWidget *button_sortbycat;
 static GtkWidget *button_sortbyfile;
 static GtkWidget *button_tree;
 static GtkWidget *button_html;
+static GtkWidget *button_xml;
+static GtkWidget *button_txt;
+static GtkWidget *button_manydirs;
 static GSList *group_sort;
+static GSList *group_html_xml;
 static GtkWidget *list_separator;
 static GtkWidget *output_entry;
 static GtkWidget *gnome_output_entry;
 static gboolean gb_check_disks;
+static gboolean gb_check_disks_only;
 static gboolean gb_check_folders;
 static gboolean gb_check_files;
 static gboolean gb_check_sizes;
+static gboolean gb_check_dates;
 static gboolean gb_check_category;
 static gboolean gb_include_vfs;
 static gboolean gb_include_dir_names;
@@ -71,6 +79,8 @@ static gboolean gb_check_only_desc;
 static gboolean gb_check_only_cat;
 static gboolean gb_spec_report;
 static gboolean gb_html_report;
+static gboolean gb_xml_report;
+static gboolean gb_manydirs_report;
 static gint cat_to_report;
 
 struct _FILE_and_int
@@ -237,25 +247,53 @@ char *nothing = "";
 char *quot;
 char *html_td_start = "<TD>";
 char *html_td_end = "</TD>";
+char *xml_report_st = "<report>";
+char *xml_report_ed = "</report>";
+char *xml_disc_name_st = "\t<disc_name><![CDATA[";
+char *xml_disc_name_ed = "]]></disc_name>\n";
+char *xml_legend_st = "<legend><![CDATA[";
+char *xml_legend_ed = "]]></legend>";
+char *xml_directory_st = "<directory>\n";
+char *xml_directory_ed = "</directory>";
+char *xml_file_st = "\t<file_name><![CDATA[";
+char *xml_file_ed = "]]></file_name>\n";
+char *xml_size_st = "\t<file_size><![CDATA[";
+char *xml_size_ed = "]]></file_size>\n";
+char *xml_date_st = "\t<file_date><![CDATA[";
+char *xml_date_ed = "]]></file_date>\n";
+char *xml_description_st = "\t<description><![CDATA[";
+char *xml_description_ed = "]]></description>\n";
+char *xml_information_st = "\t<information><![CDATA[";
+char *xml_information_ed = "]]></information>\n";
+char *xml_category_st = "\t<category><![CDATA[";
+char *xml_category_ed = "]]></category>\n";
+char *xml_location_st = "\t<directory_name><![CDATA[";
+char *xml_location_ed = "]]></directory_name>\n";
 char *td_st;
 char *td_ed;
 
 void
 set_quotes_and_separator ()
 {
-  separator = cstring (gtk_entry_get_text (GTK_ENTRY (list_separator)));
+  separator =
+    cstring ((gchar *) gtk_entry_get_text (GTK_ENTRY (list_separator)));
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_quote)) &&
-      !gb_html_report)
+      !gb_html_report && !gb_xml_report)
     quot = double_quotes;
   else
     quot = nothing;
+
   if (gb_html_report)
     {
       td_st = html_td_start;
       td_ed = html_td_end;
       separator = nothing;
     }
+  else if (gb_xml_report)
+    {
+      separator = nothing;
+    }
   else
     {
       td_st = nothing;
@@ -273,7 +311,10 @@ print_file (FILE_DATA * fd, FILE * file)
   if (is_link_dest (gn))
     return;
 
-  if (is_dir (gn) && (!gb_include_dir_names))
+  if (is_dir (gn) && (!gb_include_dir_names) && gb_check_files)
+    return;
+
+  if (!is_dir (gn) && (!is_vfs_any (gn)) && (!gb_check_files))
     return;
 
   if ((!gb_include_vfs)
@@ -284,32 +325,71 @@ print_file (FILE_DATA * fd, FILE * file)
   if ((cat_to_report != -1) && (fd->categorie != cat_to_report))
     return;
 
-  if ((gb_check_only_desc == TRUE) && (fd->description == 0))
+  if ((gb_check_only_desc) && (fd->description == 0))
     return;
-  if ((gb_check_only_cat == TRUE) && (fd->categorie == 0))
+  if ((gb_check_only_cat) && (fd->categorie == 0))
     return;
 
   if (gb_html_report)
     fprintf (file, "<TR>");
-
-  if (gb_check_disks == TRUE)
+  if (gb_xml_report)
+    fprintf (file, xml_directory_st);
+  if (gb_check_disks)
     {
-      fprintf (file, "%s%s%s%s%s%s", td_st, quot, htmlize (last_disk_name),
-	       quot, separator, td_ed);
+      if (gb_xml_report)
+	{
+	  td_st = xml_disc_name_st;
+	  td_ed = xml_disc_name_ed;
+	}
+      fprintf (file, "%s%s%s%s%s%s", td_st, quot,
+	       (last_disk_name ? htmlize (last_disk_name) : ""), quot,
+	       separator, td_ed);
     }
-  if (gb_check_folders == TRUE)
+
+  if (gb_check_folders)
     {
+      if (gb_xml_report)
+	{
+	  td_st = xml_location_st;
+	  td_ed = xml_location_ed;
+	}
       gs = get_path_from_node (gn);
       gdescr = g_strdup (gs->str);
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (no_newline)))
 	strswap (gdescr, '\n', ' ');
-      fprintf (file, "%s%s%s%s%s%s", td_st, quot, htmlize (gdescr), quot,
-	       separator, td_ed);
+      fprintf (file, "%s", td_st);
+      if (gb_manydirs_report)
+	{
+	  gchar *p1, *p2, c;
+	  p1 = gdescr;
+	  c = 1;
+	  while (c)
+	    {
+	      while (p1[0] == '/')
+		p1++;
+	      p2 = p1;
+	      while (p2[0] && (p2[0] != '/'))
+		p2++;
+	      c = p2[0];
+	      p2[0] = '\0';
+	      if (p1 != p2)
+		fprintf (file, "%s%s%s%s", quot, p1, quot, separator);
+	      p1 = p2 + 1;
+	    }
+	  fprintf (file, "%s", td_ed);
+
+	}
+      else
+	{
+	  fprintf (file, "%s%s%s%s%s", quot, htmlize (gdescr), quot,
+		   separator, td_ed);
+	}
       g_free (gdescr);
       g_string_free (gs, TRUE);
     }
 
-  if (gb_check_files == TRUE)
+  if ((gb_check_files)
+      || (((is_dir (gn) || (is_vfs_any (gn))) && (!gb_check_files))))
     {
       if (is_link (gn))
 	{
@@ -324,7 +404,12 @@ print_file (FILE_DATA * fd, FILE * file)
 	}
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (no_newline)))
 	strswap (gdescr, '\n', ' ');
-      if (is_dir (gn))
+      if (gb_xml_report)
+	{
+	  td_st = xml_file_st;
+	  td_ed = xml_file_ed;
+	}
+      if (is_dir (gn) && gb_check_files)
 	{
 	  fprintf (file, "%s%s%s/%s%s", td_st, quot, htmlize (gdescr), quot,
 		   td_ed);
@@ -336,10 +421,14 @@ print_file (FILE_DATA * fd, FILE * file)
 	}
       g_free (gdescr);
     }
-  if (gb_check_sizes == TRUE)
+  if (gb_check_sizes)
     {
-      if (!((fd->a_parent_node_is_vfs == IS_VFS)
-	    || (is_unreadable (gn) == TRUE)))
+      if (gb_xml_report)
+	{
+	  td_st = xml_size_st;
+	  td_ed = xml_size_ed;
+	}
+      if (!((fd->a_parent_node_is_vfs == IS_VFS) || (is_unreadable (gn))))
 	{
 	  fprintf (file, "%s%s%s%d%s%s", td_st, separator, quot, fd->taille,
 		   quot, td_ed);
@@ -349,8 +438,33 @@ print_file (FILE_DATA * fd, FILE * file)
 	  fprintf (file, "%s%s%s-1%s%s", td_st, separator, quot, quot, td_ed);
 	}
     }
-  if (gb_check_category == TRUE)
+  if (gb_check_dates)
     {
+      if (gb_xml_report)
+	{
+	  td_st = xml_date_st;
+	  td_ed = xml_date_ed;
+	}
+      if (!((fd->a_parent_node_is_vfs == IS_VFS) || (is_unreadable (gn))))
+	{
+	  char humandate[] = "DD/MM/YYYY HH:MM:SS ";
+	  strftime (humandate, sizeof (humandate), "%d/%m/%Y %H:%M:%S",
+		    gmtime (&fd->date));
+	  fprintf (file, "%s%s%s%s%s%s", td_st, separator, quot, humandate,
+		   quot, td_ed);
+	}
+      else
+	{
+	  fprintf (file, "%s%s%s-1%s%s", td_st, separator, quot, quot, td_ed);
+	}
+    }
+  if (gb_check_category)
+    {
+      if (gb_xml_report)
+	{
+	  td_st = xml_category_st;
+	  td_ed = xml_category_ed;
+	}
       if (fd->categorie != 0)
 	{
 	  gdescr = g_strdup (folder_get_category_from_file_data (fd));
@@ -365,8 +479,13 @@ print_file (FILE_DATA * fd, FILE * file)
     }
 
 
-  if (gb_check_description == TRUE)
+  if (gb_check_description)
     {
+      if (gb_xml_report)
+	{
+	  td_st = xml_description_st;
+	  td_ed = xml_description_ed;
+	}
       if (fd->description != 0)
 	{
 	  gdescr = g_strdup (folder_get_description_from_file_data (fd));
@@ -380,8 +499,13 @@ print_file (FILE_DATA * fd, FILE * file)
 	fprintf (file, "%s%s%s%s%s", td_st, separator, quot, quot, td_ed);
     }
 
-  if (gb_check_information == TRUE)
+  if (gb_check_information)
     {
+      if (gb_xml_report)
+	{
+	  td_st = xml_information_st;
+	  td_ed = xml_information_ed;
+	}
       if (fd->information != 0)
 	{
 	  gdescr = g_strdup (fd->information->str);
@@ -396,9 +520,12 @@ print_file (FILE_DATA * fd, FILE * file)
     }
   if (gb_html_report)
     fprintf (file, "</TR>");
+  if (gb_xml_report)
+    fprintf (file, xml_directory_ed);
   fprintf (file, "\n");
 }
 
+
 /* by tamas gervai <crown1@operamail.com> */
 void
 _report_importable_files (GNode * gn, gpointer data)
@@ -434,11 +561,11 @@ _report_files (GNode * gn, gpointer data)
 
   if (g_node_depth (gn) == 2)
     {
-      if ((gb_check_disks == TRUE)
+      if ((gb_check_disks)
 	  && ((cat_to_report == -1)
 	      || (fd->categorie == cat_to_report))
 	  && ((gb_check_only_desc == FALSE)
-	      || ((gb_check_only_desc == TRUE) && (fd->description != 0))))
+	      || ((gb_check_only_desc) && (fd->description != 0))))
 	{
 	  fprintf (file, "\n%s\n", fd->name->str);
 	  for (i = 0; i < fd->name->len; i++)
@@ -449,17 +576,16 @@ _report_files (GNode * gn, gpointer data)
   else
     {
       if (((gb_include_dir_names)
-	   && ((is_dir (gn) == TRUE) || (is_vfs_any (gn) == TRUE)))
+	   && ((is_dir (gn)) || (is_vfs_any (gn))))
 	  || ((gb_check_files)
-	      && ((is_file (gn) == TRUE) || (is_unreadable (gn) == TRUE)
-		  || (is_link (gn) == TRUE))))
+	      && ((is_file (gn)) || (is_unreadable (gn)) || (is_link (gn)))))
 	{
 	  if (((fd->categorie == cat_to_report)
 	       || (cat_to_report == -1))
 	      && ((gb_check_only_desc == FALSE)
-		  || ((gb_check_only_desc == TRUE)
+		  || ((gb_check_only_desc)
 		      && (fd->description != 0)))
-	      && ((((gb_check_only_cat == TRUE) && (fd->categorie != 0))
+	      && ((((gb_check_only_cat) && (fd->categorie != 0))
 		   || (gb_check_only_cat == FALSE))))
 	    {
 	      for (i = 0; i < g_node_depth (gn) - 1; i++)
@@ -476,17 +602,16 @@ _report_files (GNode * gn, gpointer data)
 		}
 
 
-	      if (((gb_check_category == TRUE) && (fd->categorie != 0))
+	      if (((gb_check_category) && (fd->categorie != 0))
 		  ||
-		  ((gb_check_description == TRUE)
+		  ((gb_check_description)
 		   && (fd->description != 0))
-		  || ((gb_check_information == TRUE)
-		      && (fd->information != 0)))
+		  || ((gb_check_information) && (fd->information != 0)))
 		fprintf (file, "  (");
 
 
 
-	      if ((gb_check_category == TRUE) && (fd->categorie != 0))
+	      if ((gb_check_category) && (fd->categorie != 0))
 		{
 		  if (gtk_toggle_button_get_active
 		      (GTK_TOGGLE_BUTTON (no_newline)))
@@ -503,7 +628,7 @@ _report_files (GNode * gn, gpointer data)
 			       folder_get_category_from_file_data (fd));
 		    }
 		}
-	      if ((gb_check_description == TRUE) && (fd->description != 0))
+	      if ((gb_check_description) && (fd->description != 0))
 		{
 		  if (gtk_toggle_button_get_active
 		      (GTK_TOGGLE_BUTTON (no_newline)))
@@ -520,7 +645,7 @@ _report_files (GNode * gn, gpointer data)
 			       folder_get_description_from_file_data (fd));
 		    }
 		}
-	      if ((gb_check_information == TRUE) && (fd->information != 0))
+	      if ((gb_check_information) && (fd->information != 0))
 		{
 		  if (gtk_toggle_button_get_active
 		      (GTK_TOGGLE_BUTTON (no_newline)))
@@ -536,20 +661,18 @@ _report_files (GNode * gn, gpointer data)
 			       fd->information->str);
 		    }
 		}
-	      if (((gb_check_category == TRUE) && (fd->categorie != 0))
+	      if (((gb_check_category) && (fd->categorie != 0))
 		  ||
-		  ((gb_check_description == TRUE)
+		  ((gb_check_description)
 		   && (fd->description != 0))
-		  || ((gb_check_information == TRUE)
-		      && (fd->information != 0)))
+		  || ((gb_check_information) && (fd->information != 0)))
 		fprintf (file, ")");
 
 
 
-	      if ((gb_check_folders)
-		  && ((is_dir (gn) == TRUE) || (is_vfs_any (gn) == TRUE)))
+	      if ((gb_check_folders) && ((is_dir (gn)) || (is_vfs_any (gn))))
 		{
-		  if (gb_check_location == TRUE)
+		  if (gb_check_location)
 		    {
 		      gs = get_path_from_node (gn);
 		      fprintf (file, " (%s)", gs->str);
@@ -623,7 +746,7 @@ generate_file_report (FOLDER * racine, FILE * file)
       last_disk_name = fd->name->str;
     }
 
-  if (gb_spec_report == TRUE)
+  if (gb_spec_report)
     {
       set_quotes_and_separator ();
       tmp = g_new0 (char, 1);
@@ -641,6 +764,83 @@ generate_file_report (FOLDER * racine, FILE * file)
 }
 
 
+void
+_print_disk (GNode * gn, gpointer data)
+{
+  FILE *file = data;
+  gchar *name;
+
+  set_quotes_and_separator ();
+  if (!strcmp
+      (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (disk_combo)->entry)),
+       folder_get_name (gn)))
+    {
+      ((GNode **) data)[0] = gn;
+    }
+  if (gb_html_report)
+    fprintf (file, "<TR>");
+
+  if (gb_html_report)
+    {
+      name = g_strdup (folder_get_name (gn));
+      fprintf (file, "%s%s%s%s%s%s", td_st, quot, htmlize (name),
+	       quot, separator, td_ed);
+      g_free (name);
+    }
+  else
+    fprintf (file, "%s", folder_get_name (gn));
+
+  if (gb_html_report)
+    fprintf (file, "</TR>");
+  fprintf (file, "\n");
+}
+
+
+gboolean
+generate_disk_report (FOLDER * racine, FILE * file)
+{
+  int i;
+  char *the_cat;
+
+  fprintf (stderr, "generate_disk_report()\n");
+
+  the_cat =
+    g_strdup (gtk_entry_get_text
+	      (GTK_ENTRY (GTK_COMBO (cat_combobox)->entry)));
+  cat_to_report = -2;
+  if (strlen (the_cat) == 0)
+    {
+      cat_to_report = 0;
+    }
+  else if (strcmp (the_cat, _(CATEGORY_NONE)) == 0)
+    {
+      cat_to_report = 0;
+    }
+  else if (strcmp (the_cat, _(ALL_CATEGORIES)) == 0)
+    {
+      cat_to_report = -1;
+    }
+  else
+    {
+      for (i = 1; i <= racine->categories->len; i++)
+	{
+	  if (strcmp (the_cat, get_categorie (racine, i)) == 0)
+	    cat_to_report = i;
+	}
+    }
+  g_free (the_cat);
+  if (cat_to_report == -2)
+    {
+      ERROR_DIALOG (_("Wrong category"), report_dialog_window);
+      return (FALSE);
+    }
+
+  g_node_children_foreach (racine->tree, G_TRAVERSE_ALL, _print_disk, file);
+
+  return (TRUE);
+}
+
+
 gboolean
 _report_cats (GNode * _gn, gpointer data)
 {
@@ -658,15 +858,14 @@ _report_cats (GNode * _gn, gpointer data)
   gn = fd->node;
 
   if (((gb_check_folders)
-       && ((is_dir (gn) == TRUE) || (is_vfs_any (gn) == TRUE)))
-      || ((gb_check_files == TRUE)
-	  && ((is_file (gn) == TRUE) || (is_unreadable (gn) == TRUE)
-	      || (is_link (gn) == TRUE))))
+       && ((is_dir (gn)) || (is_vfs_any (gn))))
+      || ((gb_check_files)
+	  && ((is_file (gn)) || (is_unreadable (gn)) || (is_link (gn)))))
     {
 
       if (((fd->categorie == cat) || (cat == -1))
 	  && ((gb_check_only_desc == FALSE)
-	      || ((gb_check_only_desc == TRUE) && (fd->description != 0))))
+	      || ((gb_check_only_desc) && (fd->description != 0))))
 	{
 	  last_disk_name = g_strdup (get_disk_from_node (gn));
 	  print_file (fd, file);
@@ -839,12 +1038,12 @@ begin_report_orig (GtkWidget * w, gpointer data)
 {
   FOLDER *racine = data;
 
-  char *path;
+  G_CONST_RETURN char *path;
   FILE *file;
   gboolean result;
   path = gtk_entry_get_text (GTK_ENTRY (output_entry));
 
-  if (g_file_test (path, G_FILE_TEST_ISFILE))
+  if (g_file_test (path, G_FILE_TEST_IS_REGULAR))
     {
       if (yes_no_dialog
 	  (_("remove file?"),
@@ -872,10 +1071,13 @@ begin_report_orig (GtkWidget * w, gpointer data)
     {
       gb_check_sizes =
 	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_sizes));
+      gb_check_dates =
+	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_dates));
     }
   else
     {
       gb_check_sizes = FALSE;
+      gb_check_dates = FALSE;
     }
   gb_check_location =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_location));
@@ -894,10 +1096,29 @@ begin_report_orig (GtkWidget * w, gpointer data)
   gb_check_only_desc =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_only_desc));
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbyfile)))
-    gb_html_report = FALSE;
+    {
+      gb_html_report = FALSE;
+      gb_xml_report = FALSE;
+    }
   else
-    gb_html_report =
-      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_html));
+    {
+      gb_html_report =
+	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_html));
+      gb_xml_report = !gb_html_report;
+    }
+
+  if (gb_check_disks && !gb_check_folders && !gb_check_files &&
+      !gb_check_category && !gb_check_description && !gb_check_information)
+    {
+      fprintf (stderr, "gb_check_disks_only = TRUE\n");
+      gb_check_disks_only = TRUE;
+    }
+  else
+    {
+      gb_check_disks_only = FALSE;
+    }
+  gb_manydirs_report =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_manydirs));
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_tree)))
     {
@@ -906,34 +1127,47 @@ begin_report_orig (GtkWidget * w, gpointer data)
   if (gb_html_report)
     {
       fprintf (file,
-	       "<HTML><HEAD><TITLE>%s</TITLE></HEAD><BODY>",
+	       "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">");
+      fprintf (file, "<HTML><HEAD><TITLE>%s</TITLE></HEAD><BODY>",
 	       _("GTKtalog's Catalog"));
-      fprintf (file, "<STYLE><!--\n");
+      fprintf (file, "<STYLE TYPE=\"text/css\"><!--\n");
+      fprintf (file,
+	       "body { background: white; color: black: margin: 0.5em; font-size: 9pt;}\n");
       fprintf (file, "TT { font-family: courier; }\n");
-      fprintf (file, "TD { font-family: helvetica, sans-serif; }\n");
+      fprintf (file,
+	       "TD { font-family: helvetica, sans-serif; font-size: 9pt; border-bottom: thin solid #000000; border-left: thin solid #000000;}\n");
       fprintf (file, "CAPTION {\n");
       fprintf (file, "	font-family: helvetica, sans-serif;\n");
-      fprintf (file, "	font-size: 14pt;\n");
+      fprintf (file, "	font-size: 12pt;\n");
       fprintf (file, "	text-align: left;\n");
       fprintf (file, "}\n--></STYLE>\n</HEAD><BODY>");
     }
+  if (gb_xml_report)
+    {
+      fprintf (file, "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n");
+      fprintf (file,
+	       "<?xml-stylesheet type=\"text/css\" href=\"gtktalog.css\"?>\n");
+      fprintf (file, "<report>\n");
+      fprintf (file, "<name>%s</name>\n", _("GTKtalog's Catalog"));
+    }
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (add_legend)))
     {
       if (gb_html_report)
 	fprintf (file, "<PRE>");
+      if (gb_xml_report)
+	fprintf (file, "%s\n", xml_legend_st);
       fprintf (file, _("This report was generated by GTKtalog.\n"));
       fprintf (file, GTKTALOGWEB "\n\n");
 
       fprintf (file, _("The report type is: "));
-      if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbycat))
-	  == TRUE)
+      if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbycat)))
 	{
 	  fprintf (file, _("Sort by category."));
 	}
       else
 	if (gtk_toggle_button_get_active
-	    (GTK_TOGGLE_BUTTON (button_sortbyfile)) == TRUE)
+	    (GTK_TOGGLE_BUTTON (button_sortbyfile)))
 	{
 	  fprintf (file, _("Sort by Disk->Dir->File."));
 	}
@@ -951,6 +1185,8 @@ begin_report_orig (GtkWidget * w, gpointer data)
 	fprintf (file, _("           - file name.\n"));
       if (gb_check_sizes)
 	fprintf (file, _("           - file size.\n"));
+      if (gb_check_dates)
+	fprintf (file, _("           - file date.\n"));
       if ((gb_check_location)
 	  && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_tree)))
 	fprintf (file, _("           - directory location.\n"));
@@ -971,20 +1207,24 @@ begin_report_orig (GtkWidget * w, gpointer data)
       fprintf (file, "\n");
       if (gb_html_report)
 	fprintf (file, "</PRE>");
-
+      if (gb_xml_report)
+	fprintf (file, "%s\n", xml_legend_ed);
     }
 
   if (gb_html_report)
-    fprintf (file, "<TABLE border=1><CAPTION>Catalog</CAPTION>");
+    fprintf (file, "<TABLE border=0><CAPTION>Catalog</CAPTION>");
 
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbycat))
-      == TRUE)
+  if (gb_check_disks_only)
+    {
+      result = generate_disk_report (racine, file);
+    }
+  else
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbycat)))
     {
       result = generate_cat_report (racine, file);
     }
   else
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbyfile))
-	== TRUE)
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_sortbyfile)))
     {
       result = generate_file_report (racine, file);
     }
@@ -995,8 +1235,10 @@ begin_report_orig (GtkWidget * w, gpointer data)
 
   if (gb_html_report)
     fprintf (file, "</TABLE>\n</BODY></HTML>");
+  if (gb_xml_report)
+    fprintf (file, "</report>");
   fclose (file);
-  if (result == TRUE)
+  if (result)
     WARNING_DIALOG (_("Report successful."), report_dialog_window);
 
   return;
@@ -1005,7 +1247,7 @@ begin_report_orig (GtkWidget * w, gpointer data)
 void
 begin_report (GtkWidget * w, gpointer data)
 {
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_tree)) == TRUE)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_tree)))
     gb_spec_report = FALSE;
   else
     gb_spec_report = TRUE;
@@ -1035,6 +1277,17 @@ switch_size (GtkWidget * w, gpointer data)
 							  (w)));
 }
 
+static void
+switch_report_name (GtkWidget * w, gpointer data)
+{
+  // this should set the default output to
+  // * DEFAULT_REPORT.html
+  // or
+  // * DEFAULT_REPORT.xml
+  // or
+  // * DEFAULT_REPORT.DEFAULT_EXTENSION
+}
+
 static void
 switch_dirs (GtkWidget * w, gpointer data)
 {
@@ -1076,7 +1329,7 @@ open_report_dialog (FOLDER * racine)
   gtk_window_set_wmclass (GTK_WINDOW (report_dialog_window),
 			  _("Report generator"), "GTKtalog");
   gtk_signal_connect (GTK_OBJECT (report_dialog_window), "delete_event",
-		      destroy_window, NULL);
+		      G_CALLBACK (destroy_window), NULL);
   gtk_widget_show (report_dialog_window);
 
 
@@ -1145,7 +1398,7 @@ open_report_dialog (FOLDER * racine)
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
-  table = gtk_table_new (4, 2, FALSE);
+  table = gtk_table_new (5, 2, FALSE);
   gtk_container_add (GTK_CONTAINER (frame), table);
   gtk_widget_show (table);
 
@@ -1168,6 +1421,11 @@ open_report_dialog (FOLDER * racine)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_sizes), TRUE);
   gtk_table_attach_defaults (GTK_TABLE (table), check_sizes, 0, 1, 3, 4);
   gtk_widget_show (check_sizes);
+
+  check_dates = gtk_check_button_new_with_label (_("Dates"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_dates), TRUE);
+  gtk_table_attach_defaults (GTK_TABLE (table), check_dates, 0, 1, 4, 5);
+  gtk_widget_show (check_dates);
   /* Warning: if storing the states of those buttons, this check_sizes button should be set or not
    * sensitive, depending on the check_files button.
    * Currently, the check_files button is enabled so the check_sizes button is set sensitive.
@@ -1175,6 +1433,9 @@ open_report_dialog (FOLDER * racine)
   gtk_signal_connect (GTK_OBJECT (check_files), "clicked",
 		      GTK_SIGNAL_FUNC (switch_size), check_sizes);
 
+  gtk_signal_connect (GTK_OBJECT (check_files), "clicked",
+		      GTK_SIGNAL_FUNC (switch_size), check_dates);
+
 
   check_category = gtk_check_button_new_with_label (_("Category"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_category), TRUE);
@@ -1323,13 +1584,51 @@ open_report_dialog (FOLDER * racine)
   gtk_box_pack_start (GTK_BOX (vbox2), add_legend, FALSE, FALSE, 0);
   gtk_widget_show (add_legend);
 
-  button_html = gtk_check_button_new_with_label (_("HTML"));
-  gtk_box_pack_start (GTK_BOX (vbox2), button_html, FALSE, TRUE, 0);
+  // The TEXT - HTML - XML choice radio buttons
+  hbox = gtk_hbox_new (FALSE, 2);
+  gtk_container_add (GTK_CONTAINER (vbox2), hbox);
+  gtk_container_border_width (GTK_CONTAINER (hbox), 3);
+  gtk_widget_show (hbox);
+
+  button_html = gtk_radio_button_new_with_label (NULL, _("HTML"));
+  gtk_box_pack_start (GTK_BOX (hbox), button_html, TRUE, TRUE, 0);
   gtk_widget_show (button_html);
 
+  group_html_xml = gtk_radio_button_group (GTK_RADIO_BUTTON (button_html));
+  button_xml = gtk_radio_button_new_with_label (group_html_xml, _("XML"));
+  gtk_box_pack_start (GTK_BOX (hbox), button_xml, TRUE, TRUE, 0);
+  gtk_widget_show (button_xml);
+
+  group_html_xml = gtk_radio_button_group (GTK_RADIO_BUTTON (button_html));
+  button_txt = gtk_radio_button_new_with_label (group_html_xml, _("txt"));
+  gtk_box_pack_start (GTK_BOX (hbox), button_txt, TRUE, TRUE, 0);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_txt), TRUE);
+  gtk_widget_show (button_txt);
+
   gtk_signal_connect (GTK_OBJECT (button_sortbyfile), "clicked",
 		      GTK_SIGNAL_FUNC (switch_size), button_html);
   switch_size (button_sortbyfile, button_html);
+
+  gtk_signal_connect (GTK_OBJECT (button_sortbyfile), "clicked",
+		      GTK_SIGNAL_FUNC (switch_size), button_xml);
+
+  gtk_signal_connect (GTK_OBJECT (button_sortbyfile), "clicked",
+		      GTK_SIGNAL_FUNC (switch_size), button_txt);
+
+  // Don't know the exact implementation
+  // Should connect the HTML / XML / txt radio buttons to switch_report_name-function
+  // to set the default report-name.
+  // gtk_signal_connect (GTK_OBJECT (button_html), "clicked",
+  //                  GTK_SIGNAL_FUNC (switch_report_name), "html");
+
+  button_manydirs =
+    gtk_check_button_new_with_label (_("dir1/dir2 becomes dir1,dir2"));
+  gtk_box_pack_start (GTK_BOX (vbox2), button_manydirs, FALSE, TRUE, 0);
+  gtk_widget_show (button_manydirs);
+
+  gtk_signal_connect (GTK_OBJECT (button_sortbyfile), "clicked",
+		      GTK_SIGNAL_FUNC (switch_size), button_manydirs);
+  //switch_size (button_sortbyfile, button_manydirs);
   /************/
   frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_OUT);
@@ -1353,7 +1652,7 @@ open_report_dialog (FOLDER * racine)
     gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (gnome_output_entry));
   gtk_entry_set_text (GTK_ENTRY (output_entry), report_out =
 		      g_strconcat (getenv ("HOME"), "/", DEFAULT_REPORT,
-				   NULL));
+				   ".", DEFAULT_EXTENSION, NULL));
   g_free (report_out);
   gtk_box_pack_start (GTK_BOX (hbox), gnome_output_entry, FALSE, FALSE, 0);
   gtk_widget_show (gnome_output_entry);
@@ -1377,11 +1676,15 @@ open_report_dialog (FOLDER * racine)
 		      GTK_SIGNAL_FUNC (begin_report), racine);
   gtk_widget_show (my_button);
 
+#ifdef GNOME1
   my_button = gnome_stock_button (GNOME_STOCK_BUTTON_CLOSE);
+#else
+  my_button = gtk_button_new_from_stock (GNOME_STOCK_BUTTON_CLOSE);
+#endif
   GTK_WIDGET_SET_FLAGS (my_button, GTK_CAN_DEFAULT);
   gtk_box_pack_start (GTK_BOX (hbox), my_button, TRUE, TRUE, 0);
-  gtk_signal_connect (GTK_OBJECT (my_button), "clicked", cancel_clicked,
-		      NULL);
+  gtk_signal_connect (GTK_OBJECT (my_button), "clicked",
+		      G_CALLBACK (cancel_clicked), NULL);
   gtk_widget_show (my_button);
   gtk_widget_add_accelerator (my_button, "clicked", accel_group,
 			      GDK_Escape, 0, GTK_ACCEL_VISIBLE);
