@@ -16,13 +16,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef KENAVO_LO_POTO_H__
-#define KENAVO_LO_POTO_H__
+#ifndef __REPORT_H__
+#define __REPORT_H__
 
-#include <gtk/gtk.h>
+#include <config.h>
+#include <gnome.h>
 
-void open_report_dialog(GtkWidget *w, gpointer data);
+typedef struct
+{
+}
+REPORT_WIDGETS;
 
+void _which_disk(GNode *gn, gpointer data);
+gboolean _report_cats(GNode *gn, gpointer data);
+gboolean generate_cat_report(FOLDER * racine, FILE * file);
+void _report_files(GNode *gn, gpointer data);
+gboolean generate_file_report(FOLDER *racine, FILE * file);
+void begin_report(GtkWidget *w, gpointer data);
+void set_report_file(GtkWidget *w, gpointer data);
+void select_report_file(GtkWidget *w, gpointer data);
+void open_report_dialog (FOLDER *racine);
 
 #endif
-
