@@ -273,7 +273,7 @@ switch_startstop_search (gboolean start)
 gboolean
 get_extended_search_options (FOLDER * racine)
 {
-  gchar *disk;
+  G_CONST_RETURN gchar *disk;
   gchar *tmp;
   gint mode_;
   GtkWidget *tmenu_widget;
@@ -536,7 +536,7 @@ get_extended_search_options (FOLDER * racine)
   if (strcmp (disk, STRING_ALL))
     {
       my_config->SEARCH_OPTIONS_search_root =
-	find_node_with_parent (racine->tree, disk, FALSE, racine);
+	find_node_with_parent (racine->tree, (gchar *) disk, FALSE, racine);
     }
   if (my_config->SEARCH_OPTIONS_search_root == NULL)
     {
@@ -1247,7 +1247,7 @@ create_search_dialog (FOLDER * racine)
   gtk_window_set_policy (GTK_WINDOW (search_dialog_window), FALSE, TRUE,
 			 FALSE);
   gtk_signal_connect (GTK_OBJECT (search_dialog_window), "delete_event",
-		      destroy_window, NULL);
+		      G_CALLBACK (destroy_window), NULL);
 
 /* Status and progress bar */
   appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
@@ -1290,7 +1290,7 @@ create_search_dialog (FOLDER * racine)
   simple_search_entry = gnome_entry_gtk_entry (GNOME_ENTRY (es_gnome_entry));
 
   gtk_signal_connect (GTK_OBJECT (simple_search_entry), "activate",
-		      GTK_SIGNAL_FUNC (start_search), racine);
+		      G_CALLBACK (start_search), racine);
   gtk_entry_set_text (GTK_ENTRY (simple_search_entry), "");
   gtk_widget_show (simple_search_entry);
 
@@ -1460,7 +1460,7 @@ create_search_dialog (FOLDER * racine)
       i++;
     }
   gtk_signal_connect (GTK_OBJECT (s_path_tmenu_menu), "selection-done",
-		      cb_entry_NA1, s_path_tmenu);
+		      G_CALLBACK (cb_entry_NA1), s_path_tmenu);
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (s_path_tmenu),
 			    s_path_tmenu_menu);
@@ -1585,7 +1585,7 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
-  adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+  adj = gtk_adjustment_new (1, 0, 1023, 1, 10, 10);
   size1 = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 1, 0);
   gtk_widget_show (size1);
   gtk_table_attach (GTK_TABLE (table), size1, 1, 2, 0, 1,
@@ -1596,7 +1596,7 @@ create_search_dialog (FOLDER * racine)
 			    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 							  (checksize1)));
 
-  adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+  adj = gtk_adjustment_new (1, 0, 1023, 1, 10, 10);
   size2 = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 1, 0);
   gtk_widget_show (size2);
   gtk_table_attach (GTK_TABLE (table), size2, 1, 2, 1, 2,
@@ -1658,17 +1658,17 @@ create_search_dialog (FOLDER * racine)
 							  (checksize1)));
 
   gtk_signal_connect (GTK_OBJECT (checksize1), "clicked",
-		      cb_set_sensitive, size1);
+		      G_CALLBACK (cb_set_sensitive), size1);
   gtk_signal_connect (GTK_OBJECT (checksize1), "clicked",
-		      cb_set_sensitive, size1_optionmenu);
+		      G_CALLBACK (cb_set_sensitive), size1_optionmenu);
   gtk_signal_connect (GTK_OBJECT (checksize2), "clicked",
-		      cb_set_sensitive, size2);
+		      G_CALLBACK (cb_set_sensitive), size2);
   gtk_signal_connect (GTK_OBJECT (checksize2), "clicked",
-		      cb_set_sensitive, size2_optionmenu);
+		      G_CALLBACK (cb_set_sensitive), size2_optionmenu);
   gtk_signal_connect (GTK_OBJECT (checkdate1), "clicked",
-		      cb_set_sensitive, dateedit1);
+		      G_CALLBACK (cb_set_sensitive), dateedit1);
   gtk_signal_connect (GTK_OBJECT (checkdate2), "clicked",
-		      cb_set_sensitive, dateedit2);
+		      G_CALLBACK (cb_set_sensitive), dateedit2);
 
   label = gtk_label_new (_("Date and size"));
   gtk_widget_show (label);
@@ -1756,7 +1756,7 @@ create_search_dialog (FOLDER * racine)
       i++;
     }
   gtk_signal_connect (GTK_OBJECT (desc_tmenu_menu), "selection-done",
-		      cb_entry_NA1, desc_tmenu);
+		      G_CALLBACK (cb_entry_NA1), desc_tmenu);
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (desc_tmenu), desc_tmenu_menu);
   gtk_option_menu_set_history (GTK_OPTION_MENU (desc_tmenu), 0);
@@ -1789,7 +1789,7 @@ create_search_dialog (FOLDER * racine)
       i++;
     }
   gtk_signal_connect (GTK_OBJECT (info_tmenu_menu), "selection-done",
-		      cb_entry_NA1, info_tmenu);
+		      G_CALLBACK (cb_entry_NA1), info_tmenu);
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (info_tmenu), info_tmenu_menu);
   gtk_option_menu_set_history (GTK_OPTION_MENU (info_tmenu), 0);
@@ -1904,9 +1904,9 @@ create_search_dialog (FOLDER * racine)
 
   search_list = gtk_clist_new_with_titles (8, titles);
   gtk_signal_connect (GTK_OBJECT (search_list), "select_row",
-		      GTK_SIGNAL_FUNC (selection_made), racine);
+		      G_CALLBACK (selection_made), racine);
   gtk_signal_connect (GTK_OBJECT (search_list), "unselect_row",
-		      GTK_SIGNAL_FUNC (unselection_made), racine);
+		      G_CALLBACK (unselection_made), racine);
   gtk_widget_show (search_list);
   gtk_container_add (GTK_CONTAINER (scrolled_window), search_list);
 
@@ -1914,9 +1914,9 @@ create_search_dialog (FOLDER * racine)
   gtk_widget_set_usize (GTK_WIDGET (search_list), 600, 200);
 
   gtk_signal_connect (GTK_OBJECT (search_list), "button_press_event",
-		      GTK_SIGNAL_FUNC (clist_pressed), racine);
+		      G_CALLBACK (clist_pressed), racine);
   gtk_signal_connect (GTK_OBJECT (search_list), "click_column",
-		      GTK_SIGNAL_FUNC (sort_list), racine);
+		      G_CALLBACK (sort_list), racine);
 
   hbuttonbox = gtk_hbutton_box_new ();
   gtk_widget_show (hbuttonbox);
@@ -1924,27 +1924,39 @@ create_search_dialog (FOLDER * racine)
   gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox), 15);
 
+#ifdef GNOME1
   stop_button =
     gnome_pixmap_button (gnome_stock_new_with_icon (GNOME_STOCK_PIXMAP_STOP),
 			 _("Stop Search"));
+#else
+  stop_button = gtk_button_new_with_mnemonic (_("_Stop Search"));
+#endif
   gtk_object_set_user_data (GTK_OBJECT (stop_button), NULL);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), stop_button);
-  gtk_signal_connect (GTK_OBJECT (stop_button), "clicked", stop_clicked,
-		      racine);
+  gtk_signal_connect (GTK_OBJECT (stop_button), "clicked",
+		      G_CALLBACK (stop_clicked), racine);
 
+#ifdef GNOME1
   start_button =
     gnome_pixmap_button (gnome_stock_new_with_icon
 			 (GNOME_STOCK_PIXMAP_SEARCH), _("Start Search"));
+#else
+  start_button = gtk_button_new_with_mnemonic (_("_Start Search"));
+#endif
   gtk_widget_show (start_button);
   gtk_object_set_user_data (GTK_OBJECT (start_button), NULL);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), start_button);
-  gtk_signal_connect (GTK_OBJECT (start_button), "clicked", start_search,
-		      racine);
+  gtk_signal_connect (GTK_OBJECT (start_button), "clicked",
+		      G_CALLBACK (start_search), racine);
 
+#ifdef GNOME1
   cancel_button = gnome_stock_button (GNOME_STOCK_BUTTON_CLOSE);
+#else
+  cancel_button = gtk_button_new_from_stock (GNOME_STOCK_BUTTON_CLOSE);
+#endif
   gtk_widget_show (cancel_button);
   gtk_signal_connect (GTK_OBJECT (cancel_button), "clicked",
-		      cancel_clicked, NULL);
+		      G_CALLBACK (cancel_clicked), NULL);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
   GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
 
@@ -1953,7 +1965,7 @@ create_search_dialog (FOLDER * racine)
 
   g_list_free (tcombo_items);
   gtk_signal_connect (GTK_OBJECT (less_button), "clicked",
-		      cb_set_visible, extended_search_frame);
+		      G_CALLBACK (cb_set_visible), extended_search_frame);
   cb_set_visible (less_button, extended_search_frame);
   switch_startstop_search (TRUE);
 
