@@ -22,7 +22,6 @@
 #include <config.h>
 #include <gnome.h>
 #include <time.h>
-/*#include "data.h"*/
 #include "config_common.h"
 
 typedef struct
@@ -35,11 +34,7 @@ search_info;
 
 GNode *find_node_with_parent(GNode *parent, gchar *name, gboolean case_sensitive, FOLDER * racine);
 gboolean find_files(GNode *gn, gpointer data);
-void start_search (FOLDER * racine, gboolean is_search_extended);
-void start_extended_search(GtkWidget *w, gpointer data);
-void start_simple_search(GtkWidget *w, gpointer data);
-void use_calendar1(GtkWidget *w, gpointer data);
-void use_calendar2(GtkWidget *w, gpointer data);
+void start_search (GtkWidget *w, gpointer data);
 void create_search_dialog(FOLDER *racine);
 
 #endif
