@@ -16,7 +16,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef CAMION_POUBELL_H__
-#define CAMION_POUBELL_H__
-void show_select_dir_win();
+#ifndef __SELECTDIR_H__
+#define __SELECTDIR_H__
+
+#include "config_common.h"
+
+void show_select_dir_win (FOLDER * racine);
+int start_add_disk (char *foldername, char *diskname, FOLDER * racine);
+
 #endif
