@@ -17,12 +17,17 @@
  */
 
 #include <config.h>
+#if defined(OS_FREEBSD) || defined(OS_NETBSD) || defined(OS_OPENBSD)
+#    include <sys/param.h>
+#    include <sys/mount.h>
+#endif
 #include <gnome.h>
 
 #include "config_common.h"
 #include "progressbar.h"
 
 static gint _thread_status;
+static gboolean _search_running;
 
 #if !defined(USE_PTHREADS)
 void
@@ -34,11 +39,23 @@ gui_update (void)
 #endif
 
 gint
-get_thread_status ()
+get_thread_status (void)
 {
   return (_thread_status);
 }
 
+gboolean
+is_search_running (void)
+{
+  return (_search_running);
+}
+
+void
+set_search_running (gboolean i)
+{
+  _search_running = i;
+}
+
 void
 reinit_thread_status ()
 {
@@ -57,12 +74,13 @@ set_thread_status_to_ended ()
   _thread_status = THREAD_SCAN_RUNNING_ENDED;
 }
 
-gint thread_gtk_timeout_with_progress_bar (gpointer data)
+gint
+thread_gtk_timeout_with_progress_bar (gpointer data)
 {
-gint reg = GPOINTER_TO_INT(data);
+  gint reg = GPOINTER_TO_INT (data);
   if (get_thread_status () == THREAD_SCAN_RUNNING_ENDED)
     {
-      progress_setCurrent (0, reg);
+      progress_setCurrent (0, 0, reg);
       progress_timeout (data);
 
       reinit_thread_status (reg);
@@ -71,7 +89,8 @@ gint reg = GPOINTER_TO_INT(data);
   else
     {
       progress_timeout (data);
-      gtk_timeout_add (PROGRESS_BAR_TIMEOUT, thread_gtk_timeout_with_progress_bar, data);
+      gtk_timeout_add (PROGRESS_BAR_TIMEOUT,
+		       thread_gtk_timeout_with_progress_bar, data);
     }
   return (0);
 }
