@@ -19,6 +19,10 @@
 #define _USE_BSD
 #include <config.h>
 #include <gnome.h>
+#ifdef USE_GNOMEVFS
+#include <libgnomevfs/gnome-vfs-mime.h>
+//#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#endif
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -178,14 +182,22 @@ read_one_line ()
 	      return (g_strdup (buffer));
 	    }
 	  p++;
-	} else {
-	if(errno == EAGAIN) {
-	  g_assert (p < READLINE_MAX_LENGTH);
-	  if (buffer[p] == '\n')
+	}
+      else
+	{
+	  if (errno == EAGAIN)
 	    {
-	      buffer[p] = '\0';
-	      return (g_strdup (buffer));	    }
-	} else {return(NULL);}
+	      g_assert (p < READLINE_MAX_LENGTH);
+	      if (buffer[p] == '\n')
+		{
+		  buffer[p] = '\0';
+		  return (g_strdup (buffer));
+		}
+	    }
+	  else
+	    {
+	      return (NULL);
+	    }
 	}
     }
   return (NULL);
@@ -447,8 +459,42 @@ vfs_read (GNode * gn, gchar * vfs_file_name, gint testvfs, FOLDER * racine)
   gchar **args_ptr;
   const gchar *mime;
   gboolean vfs_scan_nok = FALSE;
+#ifdef GNOME1
+#ifdef USE_GNOMEVFS
+  GnomeVFSURI *file_uri;
+#endif
+#endif
+
+  mime = NULL;
+  if (my_config->scan_mime_types)
+    {
+//printf("%s %d %s\n", __FILE__,__LINE__,vfs_file_name);
+#ifdef USE_SETJMP
+      signal (SIGALRM, sigalrm_handler);
+      alarm (5);
+      if (!setjmp (context))
+#endif
+#ifdef GNOME1
+#ifdef USE_GNOMEVFS
+	file_uri = gnome_vfs_uri_new (vfs_file_name);
+      mime = g_strdup (gnome_vfs_get_mime_type (file_uri));
+      gnome_vfs_uri_unref (file_uri);
+#else
+	mime = g_strdup (gnome_vfs_get_mime_type (vfs_file_name));
+#endif
+#else
+	mime = g_strdup (gnome_vfs_get_mime_type (vfs_file_name));
+#endif
+#ifdef USE_SETJMP
+      alarm (0);
+#endif
+//printf("%s %d %s\n", __FILE__,__LINE__,vfs_file_name);
+    }
+  if (!mime)
+    mime =
+      g_strdup (gnome_vfs_mime_type_from_name_or_default
+		(vfs_file_name, NULL));
 
-  mime = gnome_mime_type_or_default (vfs_file_name, NULL);
   if (!mime)
     return (FALSE);
 
